@@ -164,6 +164,17 @@ class CppSettings : public UmlSettings {
     // On error : return FALSE in C++, produce a RuntimeException in Java
     static bool set_IsForceNamespacePrefixGeneration(bool v);
 
+    // return if the fact an operation is inline force the header of the
+    // types referenced in the profile to be included in the header
+    
+    static bool isInlineOperationForceIncludesInHeader();
+
+    // set if the fact an operation is inline force the header of the
+    // types referenced in the profile to be included in the header
+    //
+    // On error : return FALSE in C++, produce a RuntimeException in Java
+    static bool set_IsInlineOperationForceIncludesInHeader(bool v);
+
     // return if  generate Javadoc style comment
     static bool isGenerateJavadocStyleComment();
 
@@ -210,6 +221,62 @@ class CppSettings : public UmlSettings {
     // On error : return FALSE in C++, produce a RuntimeException in Java
     static bool set_EnumReturn(QCString v);
 
+    // returns the default operation 'in' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab, else an empty string/null
+    
+    static QCString builtinIn(QCString s);
+
+    // set the default operation 'in' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab
+    //
+    // On error : return FALSE in C++, produce a RuntimeException in Java
+    
+    static bool set_BuiltinIn(QCString type, QCString form);
+
+    // returns the default operation 'out' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab, else an empty string/null
+    
+    static QCString builtinOut(QCString s);
+
+    // set the default operation 'out' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab
+    //
+    // On error : return FALSE in C++, produce a RuntimeException in Java
+    
+    static bool set_BuiltinOut(QCString type, QCString form);
+
+    // returns the default operation 'inout' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab, else an empty string/null
+    
+    static QCString builtinInOut(QCString s);
+
+    // set the default operation 'inout' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab
+    //
+    // On error : return FALSE in C++, produce a RuntimeException in Java
+    
+    static bool set_BuiltinInOut(QCString type, QCString form);
+
+    // returns the default operation 'return' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab, else an empty string/null
+    
+    static QCString builtinReturn(QCString s);
+
+    // set the default operation 'return' parameter specification
+    // in case its type is specified in the first 'Generation 
+    // settings' tab
+    //
+    // On error : return FALSE in C++, produce a RuntimeException in Java
+    
+    static bool set_BuiltinReturn(QCString type, QCString form);
+
     // returns the default operation 'in' parameter specification 
     // in case its type is not an enum or a type specified in the
     // first 'Generation settings' tab
@@ -547,6 +614,8 @@ class CppSettings : public UmlSettings {
 
     static bool _is_generate_javadoc_comment;
 
+    static bool _is_inline_force_header_in_h;
+
     static QDict<QCString> _map_includes;
 
 
