@@ -20,8 +20,10 @@ void UmlMessage::write_connectors(FileOut & out, UmlItem * diagram, const QVecto
     const char * k = msg->from()->connector(msg->to());
     
     if (connectors.find(k) == 0) {
-      k = strdup(k);
-      connectors.insert(k, k);
+      char * kk = new char[strlen(k) + 1];
+      
+      strcpy(kk, k);
+      connectors.insert(kk, kk);
       
       out.indent();
       out << "<ownedConnector xmi:type=\"uml:Connector\"";
