@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -28,12 +28,26 @@
 
 #include "UmlBaseItem.h"
 
+#ifdef ROUNDTRIP
+#include <qlist.h>
+
+class ClassContainer;
+#endif
+
 class UmlItem : public UmlBaseItem {
   public:
     UmlItem(void * id, const QCString & n)
       : UmlBaseItem(id, n) {
     };
     virtual ~UmlItem();
+    
+#ifdef ROUNDTRIP
+    virtual void upload(ClassContainer *);
+    virtual bool set_roundtrip_expected();
+    virtual void mark_useless(QList<UmlItem> & l);
+    virtual void scan_it(int & n);
+    virtual void send_it(int n);
+#endif
 };
 
 #endif
