@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -50,7 +50,7 @@ int main(int argc, char ** argv)
   
   if (UmlCom::connect(QCString(argv[port_index]).toUInt())) {
     try {
-      UmlCom::trace("<b>Python generator</b> release 1.0.8<br>");
+      UmlCom::trace("<b>Python generator</b> release 1.3<br>");
       UmlCom::traceAutoRaise(FALSE);
       
       UmlCom::targetItem()->generate();
@@ -60,13 +60,14 @@ int main(int argc, char ** argv)
       s.sprintf("<hr><font face=helvetica>Generation done : %d warnings, %d errors</font><br>",
 		n_warnings(), n_errors());
       UmlCom::trace(s);
+
+      UmlCom::showTrace();
+      UmlCom::message("");
+
+      UmlCom::bye();
     }
     catch (...) {
     }
-
-    UmlCom::showTrace();
-    UmlCom::message("");
-    UmlCom::bye();
   }
   
   UmlCom::close();
