@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -46,6 +46,7 @@
 #include "BrowserView.h"
 #include "ProfiledStereotypes.h"
 #include "mu.h"
+#include "translate.h"
 
 QList<BrowserActivityDiagram> BrowserActivityDiagram::imported;
 QValueList<int> BrowserActivityDiagram::imported_ids;
@@ -133,7 +134,7 @@ BrowserActivityDiagram *  BrowserActivityDiagram::add_activity_diagram(BrowserNo
 {
   QString name;
   
-  if (future_parent->enter_child_name(name, "enter activity diagram's name : ",
+  if (future_parent->enter_child_name(name, TR("enter activity diagram's name : "),
 				      UmlActivityDiagram, TRUE, FALSE))
     return new BrowserActivityDiagram(name, future_parent);
   else
@@ -210,36 +211,36 @@ void BrowserActivityDiagram::menu() {
   m.insertItem(new MenuTitle(name, m.font()), -1);
   m.insertSeparator();
   if (!deletedp()) {
-    m.setWhatsThis(m.insertItem("Show", 0),
-		   "to show and edit the <em>activity diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Show"), 0),
+		   TR("to show and edit the <i>activity diagram</i>"));
     if (!is_edited) {
-      m.setWhatsThis(m.insertItem("Edit", 1),
-		     "to edit the <em>activity diagram</em>");
+      m.setWhatsThis(m.insertItem(TR("Edit"), 1),
+		     TR("to edit the <i>activity diagram</i>"));
       if (!is_read_only) {
-	m.setWhatsThis(m.insertItem("Edit drawing settings", 2),
-		       "to set how the <em>activity diagram</em>'s items must be drawn");
+	m.setWhatsThis(m.insertItem(TR("Edit drawing settings"), 2),
+		       TR("to set how the <i>activity diagram</i>'s items must be drawn"));
 	m.insertSeparator();
-	m.setWhatsThis(m.insertItem("Duplicate", 3),
-		       "to duplicate the <em>activity diagram</em>");
+	m.setWhatsThis(m.insertItem(TR("Duplicate"), 3),
+		       TR("to duplicate the <i>activity diagram</i>"));
 	if (edition_number == 0) {
 	  m.insertSeparator();
-	  m.setWhatsThis(m.insertItem("Delete", 4),
-			 "to delete the <em>activity diagram</em>. \
-Note that you can undelete it after");
+	  m.setWhatsThis(m.insertItem(TR("Delete"), 4),
+			 TR("to delete the <i>activity diagram</i>. \
+Note that you can undelete it after"));
 	}
       }
     }
-    mark_menu(m, "activity diagram", 90);
+    mark_menu(m, TR("activity diagram"), 90);
     ProfiledStereotypes::menu(m, this, 99990);
     if ((edition_number == 0) && 
 	Tool::menu_insert(&toolm, get_type(), 100)) {
       m.insertSeparator();
-      m.insertItem("Tool", &toolm);
+      m.insertItem(TR("Tool"), &toolm);
     }
   }
   else if (!is_read_only && (edition_number == 0))
-    m.setWhatsThis(m.insertItem("Undelete", 5),
-		   "to undelete the <em>activity diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Undelete"), 5),
+		   TR("to undelete the <i>activity diagram</i>"));
   
   exec_menu_choice(m.exec(QCursor::pos()));
 }
@@ -250,7 +251,7 @@ void BrowserActivityDiagram::exec_menu_choice(int rank) {
     open(FALSE);
     return;
   case 1:
-    edit("Activity diagram", its_default_stereotypes);
+    edit(TR("Activity diagram"), its_default_stereotypes);
     return;
   case 2:
     edit_settings();
@@ -259,7 +260,7 @@ void BrowserActivityDiagram::exec_menu_choice(int rank) {
     {
       QString name;
       
-      if (((BrowserNode *)parent())->enter_child_name(name, "enter activity diagram's name : ",
+      if (((BrowserNode *)parent())->enter_child_name(name, TR("enter activity diagram's name : "),
 						      UmlActivityDiagram, TRUE, FALSE))
 	duplicate((BrowserNode *) parent(), name)->select_in_browser();
       else
@@ -325,21 +326,21 @@ void BrowserActivityDiagram::open(bool) {
 }
 
 void BrowserActivityDiagram::edit_settings() {
-  QArray<StateSpec> st;
-  QArray<ColorSpec> co(8);
+  StateSpecVector st;
+  ColorSpecVector co(8);
   
   settings.complete(st, TRUE);
   
-  co[0].set("activity color", &activity_color);
-  co[1].set("activity region color", &activityregion_color);
-  co[2].set("activity partition color", &activitypartition_color);
-  co[3].set("activity action color", &activityaction_color);
-  co[4].set("parameter and pin color", &parameterpin_color);
-  co[5].set("note color", &note_color);
-  co[6].set("package color", &package_color);
-  co[7].set("fragment color", &fragment_color);
+  co[0].set(TR("activity color"), &activity_color);
+  co[1].set(TR("activity region color"), &activityregion_color);
+  co[2].set(TR("activity partition color"), &activitypartition_color);
+  co[3].set(TR("activity action color"), &activityaction_color);
+  co[4].set(TR("parameter and pin color"), &parameterpin_color);
+  co[5].set(TR("note color"), &note_color);
+  co[6].set(TR("package color"), &package_color);
+  co[7].set(TR("fragment color"), &fragment_color);
   
-  SettingsDialog dialog(&st, &co, FALSE, FALSE);
+  SettingsDialog dialog(&st, &co, FALSE);
   
   dialog.raise();
   if (dialog.exec() == QDialog::Accepted) {
@@ -602,7 +603,7 @@ void BrowserActivityDiagram::save(QTextStream & st, bool ref, QString & warning)
     st << "end";
     
     // for saveAs
-    if (! is_api_base())
+    if (!is_from_lib() && !is_api_base())
       is_read_only = FALSE;
   }
 }
@@ -674,7 +675,7 @@ BrowserActivityDiagram * BrowserActivityDiagram::read(char * & st, char * k,
     read_color(st, "note_color", r->note_color, k);		// updates k
     read_color(st, "package_color", r->package_color, k);	// updates k
     read_color(st, "fragment_color", r->fragment_color, k);	// updates k
-    r->BrowserNode::read(st, k);				// updates k
+    r->BrowserNode::read(st, k, id);				// updates k
     
     if (!strcmp(k, "size")) {
       r->set_format(canvas_format(read_keyword(st)));
