@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -60,9 +60,9 @@ class BrowserActivityNode : public BrowserNode, public Labeled<BrowserActivityNo
 						  UmlCode c, const char * name);
     static BrowserActivityNode * get_activitynode(BrowserNode * future_parent, UmlCode c);
     virtual BasicData * add_relation(UmlCode, BrowserNode * end);
-    const char * may_start() const;
-    const char * may_connect(const BrowserNode * dest) const;
-    virtual const char * connexion_from(bool control) const;
+    QString may_start() const;
+    QString may_connect(const BrowserNode * dest) const;
+    virtual QString connexion_from(bool control) const;
     
     virtual const QPixmap* pixmap (int) const;
 
@@ -84,6 +84,7 @@ class BrowserActivityNode : public BrowserNode, public Labeled<BrowserActivityNo
     static void clear(bool old);
     static void update_idmax_for_root();
     virtual void renumber(int phase);
+    virtual void prepare_update_lib() const;
     
     virtual bool tool_cmd(ToolCom * com, const char * args);
     virtual bool api_compatible(unsigned v) const;
