@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -46,6 +46,7 @@
 #include "DialogUtil.h"
 #include "ProfiledStereotypes.h"
 #include "mu.h"
+#include "translate.h"
 
 // fixe bug
 #include "BrowserActivityNode.h"
@@ -99,6 +100,15 @@ void BrowserActivityPartition::update_idmax_for_root()
 {
   all.update_idmax_for_root();
 }
+
+void BrowserActivityPartition::prepare_update_lib() const {
+  all.memo_id_oid(get_ident(), original_id);
+	      
+  for (QListViewItem * child = firstChild();
+       child != 0;
+       child = child->nextSibling())
+    ((BrowserNode *) child)->prepare_update_lib();
+}
     
 void BrowserActivityPartition::referenced_by(QList<BrowserNode> & l, bool ondelete) {
   BrowserNode::referenced_by(l, ondelete);
@@ -130,7 +140,7 @@ BrowserActivityPartition *
 {
   QString name;
   
-  return (!future_parent->enter_child_name(name, "enter activity partition's \nname (may be empty) : ",
+  return (!future_parent->enter_child_name(name, TR("enter activity partition's \nname (may be empty) : "),
 					   UmlActivityPartition, TRUE, TRUE))
     
     ? 0
@@ -164,7 +174,7 @@ BrowserActivityPartition *
   BrowserNode * old;
   QString name;
   
-  if (!parent->enter_child_name(name, " enter activity \npartition's name (may be empty) : ",
+  if (!parent->enter_child_name(name, TR("enter activity partition's \nname (may be empty) : "),
 				UmlActivityPartition, l, &old,
 				TRUE, TRUE))
     return 0;
@@ -185,7 +195,7 @@ void BrowserActivityPartition::menu() {
   QString s = name;
   
   if (s.isEmpty())
-    s = "activity partition";
+    s = TR("activity partition");
   
   QPopupMenu m(0, s);
   QPopupMenu toolm(0);
@@ -194,47 +204,43 @@ void BrowserActivityPartition::menu() {
   m.insertSeparator();
   if (!deletedp()) {
     if (!is_read_only) {
-      m.setWhatsThis(m.insertItem("New sub activity partition", 0),
-		     "to add a sub <em>activity partition</em>");
+      m.setWhatsThis(m.insertItem(TR("New sub activity partition"), 0),
+		     TR("to add a sub <i>activity partition</i>"));
       m.insertSeparator();
     }
-    m.setWhatsThis(m.insertItem("Edit", 4),
-		   "to edit the <em>activity partition</em>, \
-a double click with the left mouse button does the same thing");
+    m.setWhatsThis(m.insertItem(TR("Edit"), 4),
+		   TR("to edit the <i>activity partition</i>, \
+a double click with the left mouse button does the same thing"));
     if (!is_read_only) {
-      m.setWhatsThis(m.insertItem("Duplicate", 5),
-		     "to copy the <em>activity partition</em> in a new one");
-      
-      if (((BrowserNode *) parent())->get_type() == UmlActivityPartition)
-	m.setWhatsThis(m.insertItem("Extract it from current parent partition", 12),
-		       "to stop to be nested in current parent partition");
+      m.setWhatsThis(m.insertItem(TR("Duplicate"), 5),
+		     TR("to copy the <i>activity partition</i> in a new one"));
       m.insertSeparator();
 
       if (edition_number == 0)
-	m.setWhatsThis(m.insertItem("Delete", 8),
-		       "to delete the <em>activity partition</em>. \
-Note that you can undelete it after");
+	m.setWhatsThis(m.insertItem(TR("Delete"), 8),
+		       TR("to delete the <i>activity partition</i>. \
+Note that you can undelete it after"));
     }
-    m.setWhatsThis(m.insertItem("Referenced by", 3),
-		   "to know who reference the <i>partition</i>");
-    mark_menu(m, "activity partition", 90);
+    m.setWhatsThis(m.insertItem(TR("Referenced by"), 3),
+		   TR("to know who reference the <i>partition</i>"));
+    mark_menu(m, TR("activity partition"), 90);
     ProfiledStereotypes::menu(m, this, 99990);
     if ((edition_number == 0) &&
 	Tool::menu_insert(&toolm, get_type(), 100)) {
       m.insertSeparator();
-      m.insertItem("Tool", &toolm);
+      m.insertItem(TR("Tool"), &toolm);
     }
   }
   else if (!is_read_only && (edition_number == 0)) {
-    m.setWhatsThis(m.insertItem("Undelete", 9),
-		   "to undelete the <em>activity partition</em>");
+    m.setWhatsThis(m.insertItem(TR("Undelete"), 9),
+		   TR("to undelete the <i>activity partition</i>"));
  
     QListViewItem * child;
   
     for (child = firstChild(); child != 0; child = child->nextSibling()) {
       if (((BrowserNode *) child)->deletedp()) {
-	m.setWhatsThis(m.insertItem("Undelete recursively", 10),
-		       "undelete the activity partition and its children");
+	m.setWhatsThis(m.insertItem(TR("Undelete recursively"), 10),
+		       TR("undelete the activity partition and its children"));
 	break;
       }
     }
@@ -258,7 +264,7 @@ void BrowserActivityPartition::exec_menu_choice(int rank) {
     {
       QString name;
       
-      if (((BrowserNode *) parent())->enter_child_name(name, "enter activity \npartition's name (may be empty) : ",
+      if (((BrowserNode *) parent())->enter_child_name(name, TR("enter activity partition's \nname (may be empty) : "),
 						       UmlActivityPartition, TRUE, TRUE))
 	duplicate((BrowserNode *) parent(), name)->select_in_browser();
     }
@@ -272,14 +278,6 @@ void BrowserActivityPartition::exec_menu_choice(int rank) {
   case 10:
     BrowserNode::undelete(TRUE);
     break;
-  case 12:
-    {
-      QListViewItem * p = parent();
-      
-      p->takeItem(this);
-      moveItem(p);
-    }
-    break;
   default:
     if (rank >= 99990)
       ProfiledStereotypes::choiceManagement(this, rank - 99990);
@@ -507,10 +505,33 @@ void BrowserActivityPartition::DropAfterEvent(QDropEvent * e, BrowserNode * afte
   
   if ((((bn = UmlDrag::decode(e, BrowserActivityPartition::drag_key(this))) != 0)) &&
       (bn != after) && (bn != this)) {
-    if (may_contains(bn, FALSE)) 
+    if (may_contains(bn, TRUE))  {
+      if ((after == 0) &&
+	  ((BrowserNode *) parent())->may_contains(bn, TRUE)) {
+	// have choice
+	QPopupMenu m(0);
+  
+	m.insertItem(new MenuTitle(TR("move ") + bn->get_name(),
+				   m.font()), -1);
+	m.insertSeparator();
+	m.insertItem(TR("In ") + QString(get_name()), 1);
+	m.insertItem(TR("After ") + QString(get_name()), 2);
+	
+	switch (m.exec(QCursor::pos())) {
+	case 1:
+	  break;
+	case 2:
+	  ((BrowserNode *) parent())->DropAfterEvent(e, this);
+	  return;
+	default:
+	  e->ignore();
+	  return;
+	}
+      } 
       move(bn, after);
+    }
     else {
-      msg_critical("Error", "Forbidden");
+      msg_critical(TR("Error"), TR("Forbidden"));
       e->ignore();
     }
   }
@@ -607,7 +628,7 @@ void BrowserActivityPartition::save(QTextStream & st, bool ref, QString & warnin
     st << "end";
     
     // for saveAs
-    if (! is_api_base())
+    if (!is_from_lib() && !is_api_base())
       is_read_only = FALSE;
   }
 }
@@ -674,7 +695,7 @@ BrowserActivityPartition *
       k = read_keyword(st);
     }
     
-    result->BrowserNode::read(st, k);
+    result->BrowserNode::read(st, k, id);
     
     result->is_read_only = (!in_import() && read_only_file()) || 
       ((user_id() != 0) && result->is_api_base());
