@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -46,6 +46,7 @@
 #include "BrowserView.h"
 #include "ProfiledStereotypes.h"
 #include "mu.h"
+#include "translate.h"
 
 QList<BrowserDeploymentDiagram> BrowserDeploymentDiagram::imported;
 QValueList<int> BrowserDeploymentDiagram::imported_ids;
@@ -125,7 +126,7 @@ BrowserDeploymentDiagram * BrowserDeploymentDiagram::add_deployment_diagram(Brow
 {
   QString name;
   
-  if (future_parent->enter_child_name(name, "enter deployment diagram's name : ",
+  if (future_parent->enter_child_name(name, TR("enter deployment diagram's name : "),
 				      UmlDeploymentDiagram, TRUE, FALSE))
     return new BrowserDeploymentDiagram(name, future_parent);
   else
@@ -206,36 +207,36 @@ void BrowserDeploymentDiagram::menu() {
   m.insertItem(new MenuTitle(name, m.font()), -1);
   m.insertSeparator();
   if (!deletedp()) {
-    m.setWhatsThis(m.insertItem("Show", 0),
-		   "to show and edit the <em>deployment diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Show"), 0),
+		   TR("to show and edit the <i>deployment diagram</i>"));
     if (!is_edited) {
-      m.setWhatsThis(m.insertItem("Edit", 1),
-		     "to edit the <em>deployment diagram</em>");
+      m.setWhatsThis(m.insertItem(TR("Edit"), 1),
+		     TR("to edit the <i>deployment diagram</i>"));
       if (!is_read_only) {
-	m.setWhatsThis(m.insertItem("Edit drawing settings", 2),
-		       "to set how the <em>deployment diagram</em>'s items must be drawn");
+	m.setWhatsThis(m.insertItem(TR("Edit drawing settings"), 2),
+		       TR("to set how the <i>deployment diagram</i>'s items must be drawn"));
 	m.insertSeparator();
-	m.setWhatsThis(m.insertItem("Duplicate", 3),
-		       "to duplicate the <em>class diagram</em>");
+	m.setWhatsThis(m.insertItem(TR("Duplicate"), 3),
+		       TR("to duplicate the <i>deployment diagram</i>"));
 	if (edition_number == 0) {
 	  m.insertSeparator();
-	  m.setWhatsThis(m.insertItem("Delete", 4),
-			 "to delete the <em>deployment diagram</em>. \
-Note that you can undelete it after");
+	  m.setWhatsThis(m.insertItem(TR("Delete"), 4),
+			 TR("to delete the <i>deployment diagram</i>. \
+Note that you can undelete it after"));
 	}
       }
     }
-    mark_menu(m, "deployment diagram", 90);
+    mark_menu(m, TR("deployment diagram"), 90);
     ProfiledStereotypes::menu(m, this, 99990);
     if ((edition_number == 0) &&
 	Tool::menu_insert(&toolm, get_type(), 100)) {
       m.insertSeparator();
-      m.insertItem("Tool", &toolm);
+      m.insertItem(TR("Tool"), &toolm);
     }
   }
   else if (!is_read_only && (edition_number == 0))
-    m.setWhatsThis(m.insertItem("Undelete", 5),
-		   "to undelete the <em>deployment diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Undelete"), 5),
+		   TR("to undelete the <i>deployment diagram</i>"));
   
   exec_menu_choice(m.exec(QCursor::pos()));
 }
@@ -246,7 +247,7 @@ void BrowserDeploymentDiagram::exec_menu_choice(int rank) {
     open(FALSE);
     return;
   case 1:
-    edit("Deployment diagram", its_default_stereotypes);
+    edit(TR("Deployment diagram"), its_default_stereotypes);
     return;
   case 2:
     edit_settings();
@@ -255,7 +256,7 @@ void BrowserDeploymentDiagram::exec_menu_choice(int rank) {
     {
       QString name;
       
-      if (((BrowserNode *)parent())->enter_child_name(name, "enter deployment diagram's name : ",
+      if (((BrowserNode *)parent())->enter_child_name(name, TR("enter deployment diagram's name : "),
 						      UmlDeploymentDiagram, TRUE, FALSE))
 	duplicate((BrowserNode *) parent(), name)->select_in_browser();
       else
@@ -321,19 +322,19 @@ void BrowserDeploymentDiagram::open(bool) {
 }
 
 void BrowserDeploymentDiagram::edit_settings() {
-  QArray<StateSpec> st;
-  QArray<ColorSpec> co(6);
+  StateSpecVector st;
+  ColorSpecVector co(6);
   
   settings.complete(st, TRUE);
   
-  co[0].set("note color", &note_color);
-  co[1].set("artifact color", &artifact_color);
-  co[2].set("node color", &deploymentnode_color);
-  co[3].set("component color", &component_color);
-  co[4].set("package color", &package_color);
-  co[5].set("fragment color", &fragment_color);
+  co[0].set(TR("note color"), &note_color);
+  co[1].set(TR("artifact color"), &artifact_color);
+  co[2].set(TR("node color"), &deploymentnode_color);
+  co[3].set(TR("component color"), &component_color);
+  co[4].set(TR("package color"), &package_color);
+  co[5].set(TR("fragment color"), &fragment_color);
 
-  SettingsDialog dialog(&st, &co, FALSE, FALSE);
+  SettingsDialog dialog(&st, &co, FALSE);
   
   dialog.raise();
   if (dialog.exec() == QDialog::Accepted) {
@@ -547,7 +548,7 @@ void BrowserDeploymentDiagram::save(QTextStream & st, bool ref, QString & warnin
     st << "end";
     
     // for saveAs
-    if (! is_api_base())
+    if (!is_from_lib() && !is_api_base())
       is_read_only = FALSE;
   }
 }
@@ -634,7 +635,7 @@ BrowserDeploymentDiagram *
       read_color(st, "fragment_color", r->fragment_color, k);	// updates k
     }
 
-    r->BrowserNode::read(st, k);	// updates k
+    r->BrowserNode::read(st, k, id);	// updates k
     
     if (!strcmp(k, "size")) {
       r->set_format(canvas_format(read_keyword(st)));
