@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -46,6 +46,7 @@
 #include "BrowserView.h"
 #include "ProfiledStereotypes.h"
 #include "mu.h"
+#include "translate.h"
 
 QList<BrowserObjectDiagram> BrowserObjectDiagram::imported;
 QValueList<int> BrowserObjectDiagram::imported_ids;
@@ -121,7 +122,7 @@ BrowserObjectDiagram * BrowserObjectDiagram::add_object_diagram(BrowserNode * fu
 {
   QString name;
   
-  if (future_parent->enter_child_name(name, "enter object diagram's name : ",
+  if (future_parent->enter_child_name(name, TR("enter object diagram's name : "),
 				      UmlObjectDiagram, TRUE, FALSE))
     return new BrowserObjectDiagram(name, future_parent);
   else
@@ -199,36 +200,36 @@ void BrowserObjectDiagram::menu() {
   m.insertItem(new MenuTitle(name, m.font()), -1);
   m.insertSeparator();
   if (!deletedp()) {
-    m.setWhatsThis(m.insertItem("Show", 0),
-		   "to show and edit the <em>object diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Show"), 0),
+		   TR("to show and edit the <i>object diagram</i>"));
     if (!is_edited) {
-      m.setWhatsThis(m.insertItem("Edit", 1), 
-		     "to edit the <em>object diagram</em>");
+      m.setWhatsThis(m.insertItem(TR("Edit"), 1), 
+		     TR("to edit the <i>object diagram</i>"));
       if (!is_read_only) {
-	m.setWhatsThis(m.insertItem("Edit drawing settings", 2),
-		       "to set how the <em>object diagram</em>'s items must be drawn");
+	m.setWhatsThis(m.insertItem(TR("Edit drawing settings"), 2),
+		       TR("to set how the <i>object diagram</i>'s items must be drawn"));
 	m.insertSeparator();
-	m.setWhatsThis(m.insertItem("Duplicate", 3),
-		       "to duplicate the <em>object diagram</em>");
+	m.setWhatsThis(m.insertItem(TR("Duplicate"), 3),
+		       TR("to duplicate the <i>object diagram</i>"));
 	if (edition_number == 0) {
 	  m.insertSeparator();
-	  m.setWhatsThis(m.insertItem("Delete", 4),
-			 "to delete the <em>object diagram</em>. \
-Note that you can undelete it after");
+	  m.setWhatsThis(m.insertItem(TR("Delete"), 4),
+			 TR("to delete the <i>object diagram</i>. \
+Note that you can undelete it after"));
 	}
       }
     }
-    mark_menu(m, "object diagram", 90);
+    mark_menu(m, TR("the object diagram"), 90);
     ProfiledStereotypes::menu(m, this, 99990);
     if ((edition_number == 0) &&
 	Tool::menu_insert(&toolm, get_type(), 100)) {
       m.insertSeparator();
-      m.insertItem("Tool", &toolm);
+      m.insertItem(TR("Tool"), &toolm);
     }
   }
   else if (!is_read_only && (edition_number == 0))
-    m.setWhatsThis(m.insertItem("Undelete", 5),
-		   "to undelete the <em>object diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Undelete"), 5),
+		   TR("to undelete the <i>object diagram</i>"));
   
   exec_menu_choice(m.exec(QCursor::pos()));
 }
@@ -239,7 +240,7 @@ void BrowserObjectDiagram::exec_menu_choice(int rank) {
     open(FALSE);
     break;
   case 1:
-    edit("Object diagram", its_default_stereotypes);
+    edit(TR("Object diagram"), its_default_stereotypes);
     return;
   case 2:
     edit_settings();
@@ -248,7 +249,7 @@ void BrowserObjectDiagram::exec_menu_choice(int rank) {
     {
       QString name;
       
-      if (((BrowserNode *)parent())->enter_child_name(name, "enter object diagram's name : ",
+      if (((BrowserNode *)parent())->enter_child_name(name, TR("enter object diagram's name : "),
 						      UmlObjectDiagram, TRUE, FALSE))
 	duplicate((BrowserNode *) parent(), name)->select_in_browser();
       else
@@ -315,17 +316,17 @@ void BrowserObjectDiagram::open(bool) {
 }
 
 void BrowserObjectDiagram::edit_settings() {
-  QArray<StateSpec> st;
-  QArray<ColorSpec> co(4);
+  StateSpecVector st;
+  ColorSpecVector co(4);
   
   settings.complete(st, TRUE);
   
-  co[0].set("package color", &package_color);
-  co[1].set("fragment color", &fragment_color);
-  co[2].set("note color", &note_color);
-  co[3].set("class instance \ncolor", &class_instance_color);
+  co[0].set(TR("package color"), &package_color);
+  co[1].set(TR("fragment color"), &fragment_color);
+  co[2].set(TR("note color"), &note_color);
+  co[3].set(TR("class instance \ncolor"), &class_instance_color);
   
-  SettingsDialog dialog(&st, &co, FALSE, FALSE);
+  SettingsDialog dialog(&st, &co, FALSE);
   
   dialog.raise();
   if (dialog.exec() == QDialog::Accepted) {
@@ -538,7 +539,7 @@ void BrowserObjectDiagram::save(QTextStream & st, bool ref, QString & warning) {
     st << "end";
     
     // for saveAs
-    if (! is_api_base())
+    if (!is_from_lib() && !is_api_base())
       is_read_only = FALSE;
   }
 }
@@ -607,7 +608,7 @@ BrowserObjectDiagram * BrowserObjectDiagram::read(char * & st, char * k,
     read_color(st, "note_color", r->note_color, k);	// updates k
     read_color(st, "fragment_color", r->fragment_color, k);	// updates k
     read_color(st, "package_color", r->package_color, k);	// updates k
-    r->BrowserNode::read(st, k);			// updates k
+    r->BrowserNode::read(st, k, id);			// updates k
     
     if (!strcmp(k, "size")) {
       r->set_format(canvas_format(read_keyword(st)));
