@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -78,6 +78,7 @@ class BrowserParameterSet : public BrowserNode, public Labeled<BrowserParameterS
     static void clear(bool old);
     static void update_idmax_for_root();
     virtual void renumber(int phase);
+    virtual void prepare_update_lib() const;
         
     virtual bool tool_cmd(ToolCom * com, const char * args);
     
