@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -45,10 +45,12 @@
 #include "BrowserView.h"
 #include "ProfiledStereotypes.h"
 #include "mu.h"
+#include "translate.h"
 
 QList<BrowserSeqDiagram> BrowserSeqDiagram::imported;
 QValueList<int> BrowserSeqDiagram::imported_ids;
 QStringList BrowserSeqDiagram::its_default_stereotypes;	// unicode
+QStringList BrowserSeqDiagram::message_default_stereotypes;	// unicode
 
 
 BrowserSeqDiagram::BrowserSeqDiagram(QString s, BrowserNode * p, int id)
@@ -125,7 +127,7 @@ BrowserSeqDiagram * BrowserSeqDiagram::add_sequence_diagram(BrowserNode * future
 {
   QString name;
   
-  if (future_parent->enter_child_name(name, "enter sequence diagram's name : ",
+  if (future_parent->enter_child_name(name, TR("enter sequence diagram's name : "),
 				      UmlSeqDiagram, TRUE, FALSE))
     return new BrowserSeqDiagram(name, future_parent);
   else
@@ -212,36 +214,36 @@ void BrowserSeqDiagram::menu() {
   m.insertItem(new MenuTitle(name, m.font()), -1);
   m.insertSeparator();
   if (!deletedp()) {
-    m.setWhatsThis(m.insertItem("Show", 0), 
-		   "to show and edit the <em>sequence diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Show"), 0), 
+		   TR("to show and edit the <i>sequence diagram</i>"));
     if (!is_edited) {
-      m.setWhatsThis(m.insertItem("Edit", 1),
-		     "to edit the <em>sequence diagram</em>");
+      m.setWhatsThis(m.insertItem(TR("Edit"), 1),
+		     TR("to edit the <i>sequence diagram</i>"));
       if (!is_read_only) {
-	m.setWhatsThis(m.insertItem("Edit drawing settings", 2),
-		       "to set how the <em>sequence diagram</em>'s items must be drawn");
+	m.setWhatsThis(m.insertItem(TR("Edit drawing settings"), 2),
+		       TR("to set how the <i>sequence diagram</i>'s items must be drawn"));
 	m.insertSeparator();
-	m.setWhatsThis(m.insertItem("Duplicate", 3),
-		       "to duplicate the <em>sequence diagram</em>");
+	m.setWhatsThis(m.insertItem(TR("Duplicate"), 3),
+		       TR("to duplicate the <i>sequence diagram</i>"));
 	if (edition_number == 0) {
 	  m.insertSeparator();
-	  m.setWhatsThis(m.insertItem("Delete", 4),
-			 "to delete the <em>sequence diagram</em>. \
-Note that you can undelete it after");
+	  m.setWhatsThis(m.insertItem(TR("Delete"), 4),
+			 TR("to delete the <i>sequence diagram</i>. \
+Note that you can undelete it after"));
 	}
       }
     }
-    mark_menu(m, "sequence diagram", 90);
+    mark_menu(m, TR("the sequence diagram"), 90);
     ProfiledStereotypes::menu(m, this, 99990);
     if ((edition_number == 0) &&
 	Tool::menu_insert(&toolm, get_type(), 100)) {
       m.insertSeparator();
-      m.insertItem("Tool", &toolm);
+      m.insertItem(TR("Tool"), &toolm);
     }
   }
   else if (!is_read_only && (edition_number == 0))
-    m.setWhatsThis(m.insertItem("Undelete", 5),
-		   "to undelete the <em>sequence diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Undelete"), 5),
+		   TR("to undelete the <i>sequence diagram</i>"));
   
   exec_menu_choice(m.exec(QCursor::pos()));
 }
@@ -252,7 +254,7 @@ void BrowserSeqDiagram::exec_menu_choice(int rank) {
     open(FALSE);
     break;
   case 1:
-    edit("Sequence diagram", its_default_stereotypes);
+    edit(TR("Sequence diagram"), its_default_stereotypes);
     return;
   case 2:
     edit_settings();
@@ -261,7 +263,7 @@ void BrowserSeqDiagram::exec_menu_choice(int rank) {
     {
       QString name;
       
-      if (((BrowserNode *)parent())->enter_child_name(name, "enter sequence diagram's name : ",
+      if (((BrowserNode *)parent())->enter_child_name(name, TR("enter sequence diagram's name : "),
 						      UmlSeqDiagram, TRUE, FALSE))
 	duplicate((BrowserNode *) parent(), name)->select_in_browser();
       else
@@ -328,18 +330,18 @@ void BrowserSeqDiagram::open(bool) {
 }
 
 void BrowserSeqDiagram::edit_settings() {
-  QArray<StateSpec> st;
-  QArray<ColorSpec> co(5);
+  StateSpecVector st;
+  ColorSpecVector co(5);
   
   settings.complete(st, TRUE);
   
-  co[0].set("note color", &note_color);
-  co[1].set("class instance \ncolor", &class_instance_color);
-  co[2].set("duration color", &duration_color);
-  co[3].set("continuation color", &continuation_color);
-  co[4].set("fragment color", &fragment_color);
+  co[0].set(TR("note color"), &note_color);
+  co[1].set(TR("class instance \ncolor"), &class_instance_color);
+  co[2].set(TR("duration color"), &duration_color);
+  co[3].set(TR("continuation color"), &continuation_color);
+  co[4].set(TR("fragment color"), &fragment_color);
   
-  SettingsDialog dialog(&st, &co, FALSE, FALSE);
+  SettingsDialog dialog(&st, &co, FALSE);
   
   dialog.raise();
   if (dialog.exec() == QDialog::Accepted) {
@@ -507,6 +509,9 @@ void BrowserSeqDiagram::save_stereotypes(QTextStream & st)
   nl_indent(st);
   st << "seqdiagram_stereotypes ";
   save_unicode_string_list(its_default_stereotypes, st);
+  nl_indent(st);
+  st << "msg_stereotypes ";
+  save_unicode_string_list(message_default_stereotypes, st);
 }
 
 void BrowserSeqDiagram::read_stereotypes(char * & st, char * & k)
@@ -515,6 +520,20 @@ void BrowserSeqDiagram::read_stereotypes(char * & st, char * & k)
     read_unicode_string_list(its_default_stereotypes, st);
     k = read_keyword(st);
   }
+  if (!strcmp(k, "msg_stereotypes")) {
+    read_unicode_string_list(message_default_stereotypes, st);
+    k = read_keyword(st);
+  }
+}
+
+const QStringList & BrowserSeqDiagram::default_stereotypes()
+{
+  return its_default_stereotypes;
+}
+
+const QStringList & BrowserSeqDiagram::msg_default_stereotypes()
+{
+  return message_default_stereotypes;
 }
 
 void BrowserSeqDiagram::save(QTextStream & st, bool ref, QString & warning) {
@@ -557,7 +576,7 @@ void BrowserSeqDiagram::save(QTextStream & st, bool ref, QString & warning) {
     st << "end";
     
     // for saveAs
-    if (! is_api_base())
+    if (!is_from_lib() && !is_api_base())
       is_read_only = FALSE;
   }
 }
@@ -613,7 +632,7 @@ BrowserSeqDiagram * BrowserSeqDiagram::read(char * & st, char * k,
     read_color(st, "class_instance", r->class_instance_color, k);// old release, updates k
     read_color(st, "class_instance_color", r->class_instance_color, k);// updates k
     read_color(st, "fragment_color", r->fragment_color, k);	// updates k
-    r->BrowserNode::read(st, k);			// updates k
+    r->BrowserNode::read(st, k, id);			// updates k
     
     if (!strcmp(k, "overlapping_bars"))
       // constructor set overlapping_bars to TRUE
