@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -49,7 +49,7 @@ class BrowserState : public BrowserNode, public Labeled<BrowserState> {
   protected:
     BrowserState(int id);
   
-    void exec_menu_choice(int rank, BrowserNode * item_above, bool mach);
+    void exec_menu_choice(int rank, bool mach);
     
   public:
     BrowserState(QString s, BrowserNode * p, StateData * d, int id = 0);
@@ -92,6 +92,7 @@ class BrowserState : public BrowserNode, public Labeled<BrowserState> {
     static void clear(bool old);
     static void update_idmax_for_root();
     virtual void renumber(int phase);
+    virtual void prepare_update_lib() const;
     
     virtual bool tool_cmd(ToolCom * com, const char * args);
     virtual bool api_compatible(unsigned v) const;
@@ -111,6 +112,8 @@ class BrowserState : public BrowserNode, public Labeled<BrowserState> {
     virtual void DropEvent(QDropEvent * e);
     virtual void DragMoveInsideEvent(QDragMoveEvent * e);
     virtual void DropAfterEvent(QDropEvent * e, BrowserNode * after);
+    
+    static BrowserState * get_machine(const BrowserNode * bn);
 };
 
 #endif
