@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -47,6 +47,7 @@
 #include "BrowserView.h"
 #include "ProfiledStereotypes.h"
 #include "mu.h"
+#include "translate.h"
 
 QList<BrowserUseCaseDiagram> BrowserUseCaseDiagram::imported;
 QValueList<int> BrowserUseCaseDiagram::imported_ids;
@@ -126,7 +127,7 @@ BrowserUseCaseDiagram * BrowserUseCaseDiagram::add_use_case_diagram(BrowserNode
 {
   QString name;
   
-  if (future_parent->enter_child_name(name, "enter use case diagram's name : ",
+  if (future_parent->enter_child_name(name, TR("enter use case diagram's name : "),
 				      UmlUseCaseDiagram, TRUE, FALSE))
     return new BrowserUseCaseDiagram(name, future_parent);
   else
@@ -208,36 +209,36 @@ void BrowserUseCaseDiagram::menu() {
   m.insertItem(new MenuTitle(name, m.font()), -1);
   m.insertSeparator();
   if (!deletedp()) {
-    m.setWhatsThis(m.insertItem("Show", 0),
-		   "to show and edit the <em>use case diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Show"), 0),
+		   TR("to show and edit the <i>use case diagram</i>"));
     if (!is_edited) {
-      m.setWhatsThis(m.insertItem("Edit", 1),
-		     "to edit the <em>use case diagram</em>");
+      m.setWhatsThis(m.insertItem(TR("Edit"), 1),
+		     TR("to edit the <i>use case diagram</i>"));
       if (!is_read_only) {
-	m.setWhatsThis(m.insertItem("Edit drawing settings", 2),
-		       "to set how the <em>use case diagram</em>'s items must be drawn");
+	m.setWhatsThis(m.insertItem(TR("Edit drawing settings"), 2),
+		       TR("to set how the <i>use case diagram</i>'s items must be drawn"));
 	m.insertSeparator();
-	m.setWhatsThis(m.insertItem("Duplicate", 3),
-		       "to duplicate the <em>use case diagram</em>");
+	m.setWhatsThis(m.insertItem(TR("Duplicate"), 3),
+		       TR("to duplicate the <i>use case diagram</i>"));
 	if (edition_number == 0) {
 	  m.insertSeparator();
-	  m.setWhatsThis(m.insertItem("Delete", 4),
-			 "to delete the <em>use case diagram</em>. \
-Note that you can undelete it after");
+	  m.setWhatsThis(m.insertItem(TR("Delete"), 4),
+			 TR("to delete the <i>use case diagram</i>. \
+Note that you can undelete it after"));
 	}
       }
     }
-    mark_menu(m, "use case diagram", 90);
+    mark_menu(m, TR("the use case diagram"), 90);
     ProfiledStereotypes::menu(m, this, 99990);
     if ((edition_number == 0) &&
 	Tool::menu_insert(&toolm, get_type(), 100)) {
       m.insertSeparator();
-      m.insertItem("Tool", &toolm);
+      m.insertItem(TR("Tool"), &toolm);
     }
   }
   else if (!is_read_only && (edition_number == 0))
-    m.setWhatsThis(m.insertItem("Undelete", 5),
-		   "to undelete the <em>use case diagram</em>");
+    m.setWhatsThis(m.insertItem(TR("Undelete"), 5),
+		   TR("to undelete the <i>use case diagram</i>"));
   
   exec_menu_choice(m.exec(QCursor::pos()));
 }
@@ -248,7 +249,7 @@ void BrowserUseCaseDiagram::exec_menu_choice(int rank) {
     open(FALSE);
     return;
   case 1:
-    edit("Use Case diagram", its_default_stereotypes);
+    edit(TR("Use Case diagram"), its_default_stereotypes);
     return;
   case 2:
     edit_settings();
@@ -257,7 +258,7 @@ void BrowserUseCaseDiagram::exec_menu_choice(int rank) {
     {
       QString name;
       
-      if (((BrowserNode *)parent())->enter_child_name(name, "enter use case diagram's name : ",
+      if (((BrowserNode *)parent())->enter_child_name(name, TR("enter use case diagram's name : "),
 						      UmlUseCaseDiagram, TRUE, FALSE))
 	duplicate((BrowserNode *) parent(), name)->select_in_browser();
       else
@@ -323,19 +324,19 @@ void BrowserUseCaseDiagram::open(bool) {
 }
 
 void BrowserUseCaseDiagram::edit_settings() {
-  QArray<StateSpec> st;
-  QArray<ColorSpec> co(6);
+  StateSpecVector st;
+  ColorSpecVector co(6);
   
   settings.complete(st, TRUE);
   
-  co[0].set("note color", &note_color);
-  co[1].set("use case color", &usecase_color);
-  co[2].set("package color", &package_color);
-  co[3].set("fragment color", &fragment_color);
-  co[4].set("subject color", &subject_color);
-  co[5].set("class color", &class_color);
+  co[0].set(TR("note color"), &note_color);
+  co[1].set(TR("use case color"), &usecase_color);
+  co[2].set(TR("package color"), &package_color);
+  co[3].set(TR("fragment color"), &fragment_color);
+  co[4].set(TR("subject color"), &subject_color);
+  co[5].set(TR("class color"), &class_color);
 
-  SettingsDialog dialog(&st, &co, FALSE, FALSE);
+  SettingsDialog dialog(&st, &co, FALSE);
   
   dialog.raise();
   if (dialog.exec() == QDialog::Accepted) {
@@ -561,7 +562,7 @@ void BrowserUseCaseDiagram::save(QTextStream & st, bool ref, QString & warning)
     st << "end";
     
     // for saveAs
-    if (! is_api_base())
+    if (!is_from_lib() && !is_api_base())
       is_read_only = FALSE;
   }
 }
@@ -637,7 +638,7 @@ BrowserUseCaseDiagram * BrowserUseCaseDiagram::read(char * & st, char * k,
     else
       r->class_color = UmlDefaultColor;
 
-    r->BrowserNode::read(st, k);	// updates k
+    r->BrowserNode::read(st, k, id);	// updates k
     
     if (!strcmp(k, "size")) {
       r->set_format(canvas_format(read_keyword(st)));
