@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -37,12 +37,13 @@
 #include "ToolCom.h"
 #include "mu.h"
 
-StateData::StateData() : specification(0) {
+StateData::StateData() : is_active(FALSE), specification(0) {
 }
 
 StateData::StateData(StateData * model, BrowserNode * bn)
-    : SimpleData(model) {
+    : SimpleData(model), specification(0) {
   browser_node = bn;
+  is_active = model->is_active;
   uml = model->uml;
   cpp = model->cpp;
   java = model->java;
@@ -93,13 +94,18 @@ void StateData::edit() {
   
 void StateData::send_uml_def(ToolCom * com, BrowserNode * bn,
 			     const QString & comment) {
+  int api = com->api_format();
+  
   SimpleData::send_uml_def(com, bn, comment);
   uml.send_def(com);
-  if (com->api_format() >= 45) {
+  if (api >= 45) {
     if (specification == 0)
       com->write_id(0);
     else
       specification->write_id(com);
+  
+    if (api >= 48)
+      com->write_bool(is_active);
   }
 }
 
@@ -149,6 +155,9 @@ bool StateData::tool_cmd(ToolCom * com, const char * args,
       case setDefCmd:
 	set_specification((BrowserOperation *) com->get_id(args));
         break;
+      case setActiveCmd:
+	is_active = (*args != 0);
+	break;
       default:
 	return BasicData::tool_cmd(com, args, bn, comment);
       }
@@ -172,9 +181,20 @@ void StateData::save(QTextStream & st, QString & warning) const {
   uml.save(st, "uml");
   cpp.save(st, "cpp");
   java.save(st, "java");
+
+  bool nl = FALSE;
+
+  if (is_active) {
+    nl_indent(st);
+    nl = TRUE;
+    st << "active";
+  }
   
   if (specification != 0) {
-    nl_indent(st);
+    if (nl)
+      st << " ";
+    else
+      nl_indent(st);
     st << "specification ";
     specification->save(st, TRUE, warning);
   }
@@ -185,6 +205,12 @@ void StateData::read(char * & st, char * & k) {
   uml.read(st, k, "uml");	// updates k
   cpp.read(st, k, "cpp");	// updates k
   java.read(st, k, "java");	// updates k
+  
+  if (!strcmp(k, "active")) {
+    is_active = TRUE;
+    k = read_keyword(st);
+  }
+  
   if (! strcmp(k, "specification")) {
     set_specification(BrowserOperation::read_ref(st));
     k = read_keyword(st);
