@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -38,17 +38,15 @@ class ArrowPointCanvas : public DiagramCanvas {
     virtual void delete_it();
 
     ArrowCanvas * get_other(const ArrowCanvas *) const;
-    bool attached_to(const ArrowCanvas *) const;
     
     virtual void draw(QPainter & p);
     
     virtual UmlCode type() const;
-    virtual int rtti() const;
     virtual void change_scale();
     virtual void open();
     virtual void menu(const QPoint&);
-    virtual const char * may_start(UmlCode &) const;
-    virtual const char * may_connect(UmlCode & l, const DiagramItem * dest) const;
+    virtual QString may_start(UmlCode &) const;
+    virtual QString may_connect(UmlCode & l, const DiagramItem * dest) const;
     virtual void connexion(UmlCode, DiagramItem *, const QPoint &, const QPoint &);
     virtual void delete_available(bool & in_model, bool & out_model) const;
     virtual bool alignable() const;
