@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -51,6 +51,7 @@
 #include "MenuTitle.h"
 #include "BrowserView.h"
 #include "RelatedElementsDialog.h"
+#include "translate.h"
 
 ClassDiagramView::ClassDiagramView(QWidget * parent, UmlCanvas * canvas, int id)
     : DiagramView(parent, canvas, id) {
@@ -122,7 +123,7 @@ static void get_drawn(DiagramItemList & items,
 void ClassDiagramView::menu(const QPoint& p) {
   QPopupMenu m(0);
   
-  m.insertItem(new MenuTitle("Class diagram menu", m.font()),  -1);
+  m.insertItem(new MenuTitle(TR("Class diagram menu"), m.font()),  -1);
 
   if ((((UmlCanvas *) canvas())->browser_diagram())->is_writable()) {
     BrowserNode * bn = BrowserView::selected_item();
@@ -133,14 +134,14 @@ void ClassDiagramView::menu(const QPoint& p) {
     
     if ((bn != 0) && (bn->get_type() == UmlClassView)) {      
       if (not_yet_drawn(bn, drawn)) {
-	m.insertItem("Add classes of the selected class view", 29);
+	m.insertItem(TR("Add classes of the selected class view"), 29);
 	if (marked_not_yet_drawn(drawn))
-	  m.insertItem("Add marked elements", 28);
+	  m.insertItem(TR("Add marked elements"), 28);
 	m.insertSeparator();
       }
     }
     else if (marked_not_yet_drawn(drawn))
-      m.insertItem("Add marked elements", 28);
+      m.insertItem(TR("Add marked elements"), 28);
     
     switch (default_menu(m, 30)) {
     case EDIT_DRAWING_SETTING_CMD:
@@ -302,7 +303,7 @@ void ClassDiagramView::add_marked_elements(const QPoint& p,
   QApplication::restoreOverrideCursor();
 }
 
-void ClassDiagramView::add_related_elements(DiagramItem *  di, const char * what,
+void ClassDiagramView::add_related_elements(DiagramItem *  di, QString what,
 					    bool inh, bool assoc) {
   BrowserNodeList l;
   RelatedElementsDialog dialog(di->get_bn(), what, inh, assoc, l);
