@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -50,6 +50,7 @@
 #include "ClassListDialog.h"
 #include "strutil.h"
 #include "ProfiledStereotypes.h"
+#include "translate.h"
 
 ComponentCanvas::ComponentCanvas(BrowserNode * bn, UmlCanvas * canvas,
 				 int x, int y)
@@ -349,7 +350,7 @@ bool ComponentCanvas::connexion(UmlCode action, const QPoint &, const QPoint & p
   else
     comp->get_all_required_classes(l, TRUE);
   
-  ClassListDialog dialog("Choose class", l);
+  ClassListDialog dialog(TR("Choose class"), l);
     
   if (dialog.exec() != QDialog::Accepted)
     return FALSE;
@@ -389,9 +390,9 @@ aCorner ComponentCanvas::on_resize_point(const QPoint & p) {
     : ::on_resize_point(p, rect());
 }
 
-void ComponentCanvas::resize(aCorner c, int dx, int dy) {
+void ComponentCanvas::resize(aCorner c, int dx, int dy, QPoint & o) {
   if (! as_icon)
-    DiagramCanvas::resize(c, dx, dy, min_width, min_height);
+    DiagramCanvas::resize(c, dx, dy, o, min_width, min_height, TRUE);
 }
 
 void ComponentCanvas::prepare_for_move(bool on_resize) {
@@ -766,36 +767,36 @@ void ComponentCanvas::menu(const QPoint&) {
   
   m.insertItem(new MenuTitle(browser_node->get_name(), m.font()), -1);
   m.insertSeparator();
-  m.insertItem("Upper", 0);
-  m.insertItem("Lower", 1);
-  m.insertItem("Go up", 13);
-  m.insertItem("Go down", 14);
+  m.insertItem(TR("Upper"), 0);
+  m.insertItem(TR("Lower"), 1);
+  m.insertItem(TR("Go up"), 13);
+  m.insertItem(TR("Go down"), 14);
   m.insertSeparator();
-  m.insertItem("Add related elements", 10);
+  m.insertItem(TR("Add related elements"), 10);
   m.insertSeparator();
-  m.insertItem("Edit drawing settings", 2);
+  m.insertItem(TR("Edit drawing settings"), 2);
   m.insertSeparator();
-  m.insertItem("Edit component", 3);
+  m.insertItem(TR("Edit component"), 3);
   m.insertSeparator();
-  m.insertItem("Select in browser", 4);
+  m.insertItem(TR("Select in browser"), 4);
   if (linked())
-    m.insertItem("Select linked items", 5);
+    m.insertItem(TR("Select linked items"), 5);
   m.insertSeparator();
   if (browser_node->is_writable()) {
     if (browser_node->get_associated() !=
 	(BrowserNode *) the_canvas()->browser_diagram())
-      m.insertItem("Set associated diagram",6);
+      m.insertItem(TR("Set associated diagram"),6);
     
     if (browser_node->get_associated())
-      m.insertItem("Remove diagram association",9);
+      m.insertItem(TR("Remove diagram association"),9);
   }
   m.insertSeparator();
-  m.insertItem("Remove from view", 7);
+  m.insertItem(TR("Remove from view"), 7);
   if (browser_node->is_writable())
-    m.insertItem("Delete from model", 8);
+    m.insertItem(TR("Delete from model"), 8);
   m.insertSeparator();
   if (Tool::menu_insert(&toolm, UmlComponent, 20))
-    m.insertItem("Tool", &toolm);
+    m.insertItem(TR("Tool"), &toolm);
   
   switch (index = m.exec(QCursor::pos())) {
   case 0:
@@ -846,7 +847,7 @@ void ComponentCanvas::menu(const QPoint&) {
     break;
   case 10:
     ((UmlCanvas *) canvas())->get_view()
-      ->add_related_elements(this, "component", TRUE, FALSE);
+      ->add_related_elements(this, TR("component"), TRUE, FALSE);
     return;
   default:
     if (index >= 20)
@@ -876,7 +877,7 @@ void ComponentCanvas::apply_shortcut(QString s) {
   }
   else if (s == "Add related elements") {
     ((UmlCanvas *) canvas())->get_view()
-      ->add_related_elements(this, "component", TRUE, FALSE);
+      ->add_related_elements(this, TR("component"), TRUE, FALSE);
     return;
   }
   else {
@@ -889,16 +890,16 @@ void ComponentCanvas::apply_shortcut(QString s) {
 }
 
 void ComponentCanvas::edit_drawing_settings() {
-  QArray<StateSpec> st(4);
-  QArray<ColorSpec> co(1);
+  StateSpecVector st(4);
+  ColorSpecVector co(1);
   
-  st[0].set("drawn as icon", &settings.draw_component_as_icon);
-  st[1].set("show required and provided interfaces", &settings.show_component_req_prov);
-  st[2].set("show realizations", &settings.show_component_rea);
-  st[3].set("show stereotype properties", &settings.show_stereotype_properties);
-  co[0].set("component color", &itscolor);
+  st[0].set(TR("drawn as icon"), &settings.draw_component_as_icon);
+  st[1].set(TR("show required and provided interfaces"), &settings.show_component_req_prov);
+  st[2].set(TR("show realizations"), &settings.show_component_rea);
+  st[3].set(TR("show stereotype properties"), &settings.show_stereotype_properties);
+  co[0].set(TR("component color"), &itscolor);
   
-  SettingsDialog dialog(&st, &co, FALSE, TRUE);
+  SettingsDialog dialog(&st, &co, FALSE);
   
   if (dialog.exec() == QDialog::Accepted)
     modified();	// call package_modified()
@@ -909,35 +910,35 @@ bool ComponentCanvas::has_drawing_settings() const {
 }
 
 void ComponentCanvas::edit_drawing_settings(QList<DiagramItem> & l) {
-  QArray<StateSpec> st(4);
-  QArray<ColorSpec> co(1);
+  StateSpecVector st(4);
+  ColorSpecVector co(1);
   Uml3States draw_component_as_icon;
   Uml3States show_component_req_prov;
   Uml3States show_component_rea;
   Uml3States show_stereotype_properties;
   UmlColor itscolor;
   
-  st[0].set("drawn as icon", &draw_component_as_icon);
-  st[1].set("show required and provided interfaces", &show_component_req_prov);
-  st[2].set("show realizations", &show_component_rea);
-  st[3].set("show stereotype properties", &show_stereotype_properties);
-  co[0].set("component color", &itscolor);
+  st[0].set(TR("drawn as icon"), &draw_component_as_icon);
+  st[1].set(TR("show required and provided interfaces"), &show_component_req_prov);
+  st[2].set(TR("show realizations"), &show_component_rea);
+  st[3].set(TR("show stereotype properties"), &show_stereotype_properties);
+  co[0].set(TR("component color"), &itscolor);
   
-  SettingsDialog dialog(&st, &co, FALSE, TRUE, TRUE);
+  SettingsDialog dialog(&st, &co, FALSE, TRUE);
   
   if (dialog.exec() == QDialog::Accepted) {
     QListIterator<DiagramItem> it(l);
     
     for (; it.current(); ++it) {
-      if (st[0].name != 0)
+      if (!st[0].name.isEmpty())
 	((ComponentCanvas *) it.current())->settings.draw_component_as_icon = draw_component_as_icon;
-      if (st[1].name != 0)
+      if (!st[1].name.isEmpty())
 	((ComponentCanvas *) it.current())->settings.show_component_req_prov = show_component_req_prov;
-      if (st[2].name != 0)
+      if (!st[2].name.isEmpty())
 	((ComponentCanvas *) it.current())->settings.show_component_rea = show_component_rea;
-      if (st[3].name != 0)
+      if (!st[3].name.isEmpty())
 	((ComponentCanvas *) it.current())->settings.show_stereotype_properties = show_stereotype_properties;
-      if (co[0].name != 0)
+      if (!co[0].name.isEmpty())
 	((ComponentCanvas *) it.current())->itscolor = itscolor;
       ((ComponentCanvas *) it.current())->modified();	// call package_modified()
     }
@@ -955,20 +956,20 @@ bool ComponentCanvas::get_show_stereotype_properties() const {
   }
 }
 
-const char * ComponentCanvas::may_start(UmlCode & l) const {
+QString ComponentCanvas::may_start(UmlCode & l) const {
   switch (l) {
   case UmlDependency:
     l = UmlDependOn;
-    return (browser_node->is_writable()) ? 0 : "read only";
+    return (browser_node->is_writable()) ? 0 : TR("read only");
   case UmlGeneralisation:
     l = UmlInherit;
-    return (browser_node->is_writable()) ? 0 : "read only";
+    return (browser_node->is_writable()) ? 0 : TR("read only");
   case UmlProvided:
     {
       QValueList<BrowserClass *> ll;
       
       ((BrowserComponent *) browser_node)->get_all_provided_classes(ll, FALSE);
-      return (!ll.isEmpty()) ? 0 : "no provided interfaces";
+      return (!ll.isEmpty()) ? 0 : TR("no provided interfaces");
     }
     break;
   case UmlRequired:
@@ -976,13 +977,13 @@ const char * ComponentCanvas::may_start(UmlCode & l) const {
       QValueList<BrowserClass *> ll;
       
       ((BrowserComponent *) browser_node)->get_all_required_classes(ll, FALSE);
-      return (!ll.isEmpty()) ? 0 : "no required interfaces";
+      return (!ll.isEmpty()) ? 0 : TR("no required interfaces");
     }
     break;
   case UmlAnchor:
     return 0;
   default:
-    return "illegal";
+    return TR("illegal");
   }
 }
 
@@ -996,7 +997,7 @@ bool ComponentCanvas::may_connect(UmlCode l) const {
   }
 }
 
-const char * ComponentCanvas::may_connect(UmlCode & l, const DiagramItem * dest) const {
+QString ComponentCanvas::may_connect(UmlCode & l, const DiagramItem * dest) const {
   if (l == UmlAnchor)
     return dest->may_start(l);
   
@@ -1008,7 +1009,7 @@ const char * ComponentCanvas::may_connect(UmlCode & l, const DiagramItem * dest)
     case UmlInherit:
       return browser_node->check_inherit(dest->get_bn());
     default:
-      return "illegal";
+      return TR("illegal");
     }
   case UmlArrowJunction:
     switch (l) {
@@ -1018,7 +1019,7 @@ const char * ComponentCanvas::may_connect(UmlCode & l, const DiagramItem * dest)
       
       ((BrowserComponent *) browser_node)->get_all_required_classes(ll, FALSE);
       return (ll.findIndex(((ArrowJunctionCanvas *) dest)->get_interface()) != -1)
-	? 0 : "not required";
+	? 0 : TR("not required");
     }
     case UmlProvided:
     {
@@ -1026,13 +1027,13 @@ const char * ComponentCanvas::may_connect(UmlCode & l, const DiagramItem * dest)
       
       ((BrowserComponent *) browser_node)->get_all_provided_classes(ll, FALSE);
       return (ll.findIndex(((ArrowJunctionCanvas *) dest)->get_interface()) != -1)
-	? 0 : "not provided";
+	? 0 : TR("not provided");
     }
     default:
-      return "illegal";
+      return TR("illegal");
     }
   default:
-    return "illegal";
+    return TR("illegal");
   }
 }
 
