@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -83,7 +83,7 @@ class DiagramCanvas : public QCanvasRectangle, public DiagramItem {
     void set_center100();
     virtual bool contains(int, int) const;
     
-    void resize(aCorner c, int dx, int dy, int min_width, int min_height,
+    void resize(aCorner c, int dx, int dy, QPoint &, int min_width, int min_height,
 		bool odd = FALSE, bool stay_centered = FALSE);
     virtual void resize(int w, int h);
     virtual UmlCanvas * the_canvas() const;
