@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -41,79 +41,80 @@
 #include "BrowserObjectDiagram.h"
 #include "UmlPixmap.h"
 #include "myio.h"
+#include "translate.h"
 
-extern const char * addmodeledclassinstanceText;
-extern const char * addclassinstanceText;
-extern const char * addpackageText;
-extern const char * addfragmentText;
-extern const char * noteText;
-extern const char * anchorText;
-static const char * linkText = "Click this button to add a <em>link</em> between instances";
-extern const char * textText;
+extern QString addmodeledclassinstanceText();
+extern QString addclassinstanceText();
+extern QString addpackageText();
+extern QString addfragmentText();
+extern QString noteText();
+extern QString anchorText();
+static QString linkText() { return TR("Click this button to add a <i>link</i> between instances"); }
+extern QString textText();
 
 // id is an old ident in case of an import
 ObjectDiagramWindow::ObjectDiagramWindow(const QString & s, BrowserObjectDiagram * b, int id)
     : DiagramWindow(b, s), view(0) {
   QToolBar * toolbar = new QToolBar(this, "object diagram operations");
-  addToolBar(toolbar, "Object Diagram Operations", Top, TRUE);
+  addToolBar(toolbar, TR("Toolbar"), Top, TRUE);
   
   add_edit_button(toolbar);
   
   select =
-    new QToolButton(*selectButton, "Select", QString::null,
+    new QToolButton(*selectButton, TR("Select"), QString::null,
 		    this, SLOT(hit_select()), toolbar, "select");
   select->setToggleButton(TRUE);
   select->setOn(TRUE);
   current_button = UmlSelect;
   
   addPackage
-    = new QToolButton(*packageButton, "Add Package", QString::null,
+    = new QToolButton(*packageButton, TR("Add Package"), QString::null,
 		      this, SLOT(hit_package()), toolbar, "add package");
   addPackage->setToggleButton(TRUE);
-  QWhatsThis::add(addPackage, addpackageText);
+  QWhatsThis::add(addPackage, addpackageText());
   
   addFragment
-    = new QToolButton(*fragmentButton, "Add Fragment", QString::null,
+    = new QToolButton(*fragmentButton, TR("Add Fragment"), QString::null,
 		      this, SLOT(hit_fragment()), toolbar, "add fragment");
   addFragment->setToggleButton(TRUE);
-  QWhatsThis::add(addFragment, addfragmentText);
+  QWhatsThis::add(addFragment, addfragmentText());
   
   addClassInstance
-    = new QToolButton(*classinstanceButton, "Add modeled Class instance", QString::null,
+    = new QToolButton(*classinstanceButton, TR("Add modeled Class instance"), QString::null,
 		      this, SLOT(hit_classinstance()), toolbar,
 		      "add modeled class instance");
   addClassInstance->setToggleButton(TRUE);
-  QWhatsThis::add(addClassInstance, addmodeledclassinstanceText);
+  QWhatsThis::add(addClassInstance, addmodeledclassinstanceText());
   
   addClass
-    = new QToolButton(*classButton, "Add Class instance", QString::null,
+    = new QToolButton(*classButton, TR("Add Class instance"), QString::null,
 		      this, SLOT(hit_class()), toolbar, "add class instance");
   addClass->setToggleButton(TRUE);
-  QWhatsThis::add(addClass, addclassinstanceText);
+  QWhatsThis::add(addClass, addclassinstanceText());
   
   addLink =
-    new QToolButton(*associationButton, "Add Link between instances", QString::null,
+    new QToolButton(*associationButton, TR("Add Link between instances"), QString::null,
 		    this, SLOT(hit_link()), toolbar, "add link between instances");
   addLink->setToggleButton(TRUE);
-  QWhatsThis::add(addLink, linkText);
+  QWhatsThis::add(addLink, linkText());
   
   note =
-    new QToolButton(*noteButton, "Note", QString::null,
+    new QToolButton(*noteButton, TR("Note"), QString::null,
 		    this, SLOT(hit_note()), toolbar, "note");
   note->setToggleButton(TRUE);
-  QWhatsThis::add(note, noteText);
+  QWhatsThis::add(note, noteText());
   
   anchor =
-    new QToolButton(*anchorButton, "Anchor", QString::null,
+    new QToolButton(*anchorButton, TR("Anchor"), QString::null,
 		    this, SLOT(hit_anchor()), toolbar, "anchor");
   anchor->setToggleButton(TRUE);
-  QWhatsThis::add(anchor, anchorText);
+  QWhatsThis::add(anchor, anchorText());
   
   text =
-    new QToolButton(*textButton, "Text", QString::null,
+    new QToolButton(*textButton, TR("Text"), QString::null,
 		    this, SLOT(hit_text()), toolbar, "text");
   text->setToggleButton(TRUE);
-  QWhatsThis::add(text, textText);
+  QWhatsThis::add(text, textText());
   
   toolbar->addSeparator();
   
