@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -50,6 +50,7 @@
 #include "MenuTitle.h"
 #include "Settings.h"
 #include "strutil.h"
+#include "translate.h"
 
 ParameterCanvas::ParameterCanvas(BrowserNode * bn, UmlCanvas * canvas,
 				 int x, int y, int id, ActivityCanvas * a)
@@ -183,10 +184,10 @@ aCorner ParameterCanvas::on_resize_point(const QPoint & p) {
   return ::on_resize_point(p, rect());
 }
 
-void ParameterCanvas::resize(aCorner c, int dx, int dy) {
+void ParameterCanvas::resize(aCorner c, int dx, int dy, QPoint & o) {
   double zoom = the_canvas()->zoom();
   
-  DiagramCanvas::resize(c, dx, dy,
+  DiagramCanvas::resize(c, dx, dy, o,
 			(int) (PARAMETER_CANVAS_MIN_WIDTH * zoom),
 			(int) (PARAMETER_CANVAS_MIN_HEIGHT * zoom),
 			TRUE, TRUE);
@@ -309,28 +310,28 @@ void ParameterCanvas::menu(const QPoint &) {
   
   m.insertItem(new MenuTitle(browser_node->get_name(), m.font()), -1);
   m.insertSeparator();
-  m.insertItem("Upper", 0);
-  m.insertItem("Lower", 1);
-  m.insertItem("Go up", 13);
-  m.insertItem("Go down", 14);
+  m.insertItem(TR("Upper"), 0);
+  m.insertItem(TR("Lower"), 1);
+  m.insertItem(TR("Go up"), 13);
+  m.insertItem(TR("Go down"), 14);
   m.insertSeparator();
-  m.insertItem("Edit drawing settings", 2);
+  m.insertItem(TR("Edit drawing settings"), 2);
   if (params.count() > 1)
-    m.insertItem("Resize other like it", 6);
+    m.insertItem(TR("Resize other like it"), 6);
   m.insertSeparator();
-  m.insertItem("Edit parameter", 3);
+  m.insertItem(TR("Edit parameter"), 3);
   m.insertSeparator();
-  m.insertItem("Select in browser", 4);
+  m.insertItem(TR("Select in browser"), 4);
   if (cl != 0)
-    m.insertItem("Select class in browser", 9);
+    m.insertItem(TR("Select class in browser"), 9);
   if (linked())
-    m.insertItem("Select linked items", 5);
+    m.insertItem(TR("Select linked items"), 5);
   m.insertSeparator();
   if (browser_node->is_writable())
-    m.insertItem("Delete from model", 8);
+    m.insertItem(TR("Delete from model"), 8);
   m.insertSeparator();
   if (Tool::menu_insert(&toolm, UmlParameter, 20))
-    m.insertItem("Tool", &toolm);
+    m.insertItem(TR("Tool"), &toolm);
   
   switch (index = m.exec(QCursor::pos())) {
   case 0:
@@ -421,11 +422,11 @@ void ParameterCanvas::apply_shortcut(QString s) {
 }
 
 void ParameterCanvas::edit_drawing_settings() {
-  QArray<ColorSpec> co(1);
+  ColorSpecVector co(1);
   
-  co[0].set("parameter node color", &itscolor);
+  co[0].set(TR("parameter node color"), &itscolor);
   
-  SettingsDialog dialog(0, &co, FALSE, TRUE);
+  SettingsDialog dialog(0, &co, FALSE);
   
   dialog.raise();
   if (dialog.exec() == QDialog::Accepted)
@@ -437,15 +438,15 @@ bool ParameterCanvas::has_drawing_settings() const {
 }
 
 void ParameterCanvas::edit_drawing_settings(QList<DiagramItem> & l) {
-  QArray<ColorSpec> co(1);
+  ColorSpecVector co(1);
   UmlColor itscolor;
   
-  co[0].set("parameter node color", &itscolor);
+  co[0].set(TR("parameter node color"), &itscolor);
   
-  SettingsDialog dialog(0, &co, FALSE, TRUE, TRUE);
+  SettingsDialog dialog(0, &co, FALSE, TRUE);
   
   dialog.raise();
-  if ((dialog.exec() == QDialog::Accepted) && (co[0].name != 0)) {
+  if ((dialog.exec() == QDialog::Accepted) && !co[0].name.isEmpty()) {
     QListIterator<DiagramItem> it(l);
     
     for (; it.current(); ++it) {
@@ -455,22 +456,22 @@ void ParameterCanvas::edit_drawing_settings(QList<DiagramItem> & l) {
   }
 }
 
-const char * ParameterCanvas::may_start(UmlCode & l) const {
+QString ParameterCanvas::may_start(UmlCode & l) const {
   switch (l) {
   case UmlFlow:
     return ((BrowserParameter *) browser_node)->may_start();
   case UmlDependOn:
-    return "illegal";
+    return TR("illegal");
   default: // anchor
     return 0;
   }
 }
 
-const char * ParameterCanvas::may_connect(UmlCode & l, const DiagramItem * dest) const {
+QString ParameterCanvas::may_connect(UmlCode & l, const DiagramItem * dest) const {
   if (l == UmlAnchor)
     return dest->may_start(l);
   else if(dest->get_bn() == 0)
-    return "illegal";
+    return TR("illegal");
   else
     return ((BrowserParameter *) browser_node)->may_connect(dest->get_bn());
 }
