@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -48,14 +48,14 @@ class TextCanvas : public DiagramCanvas {
     virtual UmlCode type() const;
     virtual void open();
     virtual void menu(const QPoint&);
-    virtual const char * may_start(UmlCode &) const;
-    virtual const char * may_connect(UmlCode & l, const DiagramItem * dest) const;
+    virtual QString may_start(UmlCode &) const;
+    virtual QString may_connect(UmlCode & l, const DiagramItem * dest) const;
     virtual void delete_available(bool & in_model, bool & out_model) const;
     virtual bool alignable() const;
     virtual bool copyable() const;
     virtual bool move_with(UmlCode) const;
     virtual aCorner on_resize_point(const QPoint &);
-    virtual void resize(aCorner c, int dx, int dy);
+    virtual void resize(aCorner c, int dx, int dy, QPoint &);
     virtual void apply_shortcut(QString s);
     virtual void history_save(QBuffer &) const;
     virtual void history_load(QBuffer &);
