@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -35,6 +35,7 @@
 #include "ClassSettingsDialog.h"
 #include "Settings.h"
 #include "UmlDesktop.h"
+#include "translate.h"
     
 
 class ComboVisibility : public QComboBox {
@@ -57,7 +58,7 @@ QSize ClassSettingsDialog::previous_size;
 
 ClassSettingsDialog::ClassSettingsDialog(ClassSettings * se, bool nodefault)
     : QDialog(0, "Class Settings dialog", TRUE), settings(se) {
-  setCaption("Class Settings dialog");
+  setCaption(TR("Class Settings dialog"));
   
   QVBoxLayout * vbox = new QVBoxLayout(this);  
   QHBoxLayout * hbox;
@@ -67,26 +68,26 @@ ClassSettingsDialog::ClassSettingsDialog(ClassSettings * se, bool nodefault)
   
   hbox = new QHBoxLayout(vbox); 
   hbox->setMargin(5);
-  hbox->addWidget(new QLabel("default attributes visibility : ", this), 1000);
+  hbox->addWidget(new QLabel(TR("default attributes visibility : "), this), 1000);
   cbattribute = new ComboVisibility(this, settings->attribute_visibility, nodefault);
   hbox->addWidget(cbattribute);
 
   hbox = new QHBoxLayout(vbox); 
   hbox->setMargin(5);
-  hbox->addWidget(new QLabel("default relations visibility : ", this), 1000);
+  hbox->addWidget(new QLabel(TR("default relations visibility : "), this), 1000);
   cbrelation = new ComboVisibility(this, settings->relation_visibility, nodefault);
   hbox->addWidget(cbrelation);
 
   hbox = new QHBoxLayout(vbox); 
   hbox->setMargin(5);
-  hbox->addWidget(new QLabel("default operations visibility : ", this), 1000);
+  hbox->addWidget(new QLabel(TR("default operations visibility : "), this), 1000);
   cboperation = new ComboVisibility(this, settings->operation_visibility, nodefault);
   hbox->addWidget(cboperation);
 
   hbox = new QHBoxLayout(vbox); 
   hbox->setMargin(5);
-  QPushButton * accept = new QPushButton("&OK", this);
-  QPushButton * cancel = new QPushButton("&Cancel", this);
+  QPushButton * accept = new QPushButton(TR("&OK"), this);
+  QPushButton * cancel = new QPushButton(TR("&Cancel"), this);
   QSize bs(cancel->sizeHint());
   
   accept->setDefault(TRUE);  
