@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -35,6 +35,7 @@
 #include "DecoratorDialog.h"
 #include "UmlDesktop.h"
 #include "BrowserClass.h"
+#include "translate.h"
 
 QSize DecoratorDialog::previous_size;
 
@@ -44,6 +45,8 @@ static const char * DefaultDecorators[] = {
 
 DecoratorDialog::DecoratorDialog(QWidget * parent, QString & s, bool visit)
     : QDialog(parent, "decorator editor", TRUE), value(s) {
+  setCaption(TR("decorator dialog"));
+  
   QVBoxLayout * vbox = new QVBoxLayout(this);
 
   vbox->setMargin(5);
@@ -60,10 +63,10 @@ DecoratorDialog::DecoratorDialog(QWidget * parent, QString & s, bool visit)
     // to choose and add an decorator
     
     QLabel * label =
-      new QLabel("\nTo add an decorator at the cursor position\n"
-		 "you may select it in the list and press 'add'\n"
-		 "\nSet operation static to add @staticmethod,\n"
-		 "set operation abstract to add @abstractmethod\n",
+      new QLabel(TR("\nTo add an decorator at the cursor position\n"
+		    "you may select it in the list and press 'add'\n"
+		    "\nSet operation static to add @staticmethod,\n"
+		    "set operation abstract to add @abstractmethod\n"),
 		 this);
     label->setAlignment(Qt::AlignCenter);
     vbox->addWidget(label);
@@ -72,7 +75,7 @@ DecoratorDialog::DecoratorDialog(QWidget * parent, QString & s, bool visit)
     QPushButton * add_button;
     
     hbox->setMargin(5);
-    add_button = new QPushButton("Add ", this);
+    add_button = new QPushButton(TR("Add "), this);
     hbox->addWidget(add_button);  
     connect(add_button, SIGNAL(clicked()), this, SLOT(add_decorator()));
     
@@ -82,7 +85,7 @@ DecoratorDialog::DecoratorDialog(QWidget * parent, QString & s, bool visit)
     
     sp.setHorData(QSizePolicy::Expanding);
     cb->setSizePolicy(sp);
-    cb->setAutoCompletion(TRUE);
+    cb->setAutoCompletion(completion());
     
     for (int i = 0;
 	 i != sizeof(DefaultDecorators)/sizeof(*DefaultDecorators);
@@ -105,8 +108,8 @@ DecoratorDialog::DecoratorDialog(QWidget * parent, QString & s, bool visit)
     
     hbox = new QHBoxLayout(vbox);
     hbox->setMargin(5);
-    QPushButton * accept = new QPushButton("&OK", this);
-    QPushButton * cancel = new QPushButton("&Cancel", this);
+    QPushButton * accept = new QPushButton(TR("&OK"), this);
+    QPushButton * cancel = new QPushButton(TR("&Cancel"), this);
     QSize bs(cancel->sizeHint());
     
     accept->setDefault( TRUE );
@@ -129,7 +132,7 @@ DecoratorDialog::DecoratorDialog(QWidget * parent, QString & s, bool visit)
     QHBoxLayout * hbox = new QHBoxLayout(vbox);
     
     hbox->setMargin(5);
-    QPushButton * close = new QPushButton("&Close", this);
+    QPushButton * close = new QPushButton(TR("&Close"), this);
 
     hbox->addWidget(close);
     
