@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -51,6 +51,7 @@
 #include "strutil.h"
 #include "BodyDialog.h"
 #include "ProfiledStereotypes.h"
+#include "translate.h"
 
 QSize PinDialog::previous_size;
 
@@ -58,15 +59,17 @@ PinDialog::PinDialog(PinData * pi)
     : QTabDialog(0, 0, FALSE, WDestructiveClose), pin(pi) {
   pi->browser_node->edit_start();
   
-  if (pi->browser_node->is_writable())
-    setCancelButton();
+  if (pi->browser_node->is_writable()) {
+    setOkButton(TR("OK"));
+    setCancelButton(TR("Cancel"));
+  }
   else {
     setOkButton(QString::null);
-    setCancelButton("Close");
+    setCancelButton(TR("Close"));
   }
 
   visit = !hasOkButton();
-  setCaption("Pin dialog");
+  setCaption(TR("Pin dialog"));
   
   QGrid * grid;
   QHBox * htab;
@@ -79,7 +82,7 @@ PinDialog::PinDialog(PinData * pi)
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("name :", grid);
+  new QLabel(TR("name :"), grid);
   edname = new LineEdit(pi->name(), grid);
   edname->setReadOnly(visit);
 
@@ -88,13 +91,13 @@ PinDialog::PinDialog(PinData * pi)
     font.setFamily("Courier");
   font.setFixedPitch(TRUE);
   
-  new QLabel("stereotype : ", grid);
+  new QLabel(TR("stereotype : "), grid);
   edstereotype = new QComboBox(!visit, grid);
   edstereotype->insertItem(toUnicode(pi->stereotype));
   if (! visit) {
     edstereotype->insertStringList(BrowserPin::default_stereotypes());
     edstereotype->insertStringList(ProfiledStereotypes::defaults(UmlActivityPin));
-    edstereotype->setAutoCompletion(TRUE);
+    edstereotype->setAutoCompletion(completion());
   }
   edstereotype->setCurrentItem(0);
   
@@ -103,7 +106,7 @@ PinDialog::PinDialog(PinData * pi)
   sp.setHorData(QSizePolicy::Expanding);
   edstereotype->setSizePolicy(sp);
     
-  connect(new SmallPushButton("type :", grid), SIGNAL(clicked()),
+  connect(new SmallPushButton(TR("type :"), grid), SIGNAL(clicked()),
 	  this, SLOT(menu_type()));
   
   edtype = new QComboBox(!visit, grid);
@@ -115,13 +118,13 @@ PinDialog::PinDialog(PinData * pi)
     edtype->insertStringList(GenerationSettings::basic_types());
     offset = edtype->count();
     edtype->insertStringList(list);
-    edtype->setAutoCompletion(TRUE);
+    edtype->setAutoCompletion(completion());
     view = pi->browser_node->container(UmlClass);
   }
   edtype->setCurrentItem(0);
   edtype->setSizePolicy(sp);
   
-  new QLabel("direction :", grid);
+  new QLabel(TR("direction :"), grid);
   htab = new QHBox(grid);
   eddir = new QComboBox(FALSE, htab);
   
@@ -138,7 +141,7 @@ PinDialog::PinDialog(PinData * pi)
       eddir->insertItem(stringify(UmlReturn));
   }
   
-  new QLabel("   multiplicity : ", htab);
+  new QLabel(TR("   multiplicity : "), htab);
   edmultiplicity = new QComboBox(!visit, htab);
   edmultiplicity->setSizePolicy(sp);
   edmultiplicity->insertItem(pi->get_multiplicity());
@@ -149,7 +152,7 @@ PinDialog::PinDialog(PinData * pi)
     edmultiplicity->insertItem("1..*");
   }
   
-  new QLabel("   ordering : ", htab);
+  new QLabel(TR("   ordering : "), htab);
   edordering = new QComboBox(FALSE, htab);
   
   UmlOrderingKind o = pi->get_ordering();
@@ -166,7 +169,7 @@ PinDialog::PinDialog(PinData * pi)
       edordering->insertItem(stringify(UmlFifo));
   }
     
-  new QLabel("   effect : ", htab);
+  new QLabel(TR("   effect : "), htab);
   edeffect = new QComboBox(FALSE, htab);
   
   UmlParamEffect e = pi->get_effect();
@@ -185,7 +188,7 @@ PinDialog::PinDialog(PinData * pi)
       edeffect->insertItem(stringify(UmlDelete));
   }
     
-  new QLabel("in state : ", grid);
+  new QLabel(TR("in state : "), grid);
   edin_state = new LineEdit(pi->in_state, grid);
   edin_state->setReadOnly(visit);
        
@@ -194,12 +197,12 @@ PinDialog::PinDialog(PinData * pi)
   QButtonGroup * bg = 
     new QButtonGroup(2, Qt::Horizontal, QString::null, htab);
   
-  is_control_cb = new QCheckBox("is_control", bg);
+  is_control_cb = new QCheckBox(TR("is_control"), bg);
   if (pi->is_control)
     is_control_cb->setChecked(TRUE);
   is_control_cb->setDisabled(visit);
   
-  unique_cb = new QCheckBox("unique", bg);
+  unique_cb = new QCheckBox(TR("unique"), bg);
   if (pi->unique)
     unique_cb->setChecked(TRUE);
   unique_cb->setDisabled(visit);
@@ -208,9 +211,9 @@ PinDialog::PinDialog(PinData * pi)
     new QButtonGroup(3, Qt::Horizontal, QString::null, htab);
   bg->setExclusive(TRUE);
   
-  standard_rb = new QRadioButton("standard", bg);
-  exception_rb = new QRadioButton("exception", bg);
-  stream_rb = new QRadioButton("stream", bg);
+  standard_rb = new QRadioButton(TR("standard"), bg);
+  exception_rb = new QRadioButton(TR("exception"), bg);
+  stream_rb = new QRadioButton(TR("stream"), bg);
   
   if (pi->exception)
     exception_rb->setChecked(TRUE);
@@ -220,9 +223,9 @@ PinDialog::PinDialog(PinData * pi)
     standard_rb->setChecked(TRUE);
   
   QVBox * vtab = new QVBox(grid);
-  new QLabel("description :", vtab);
+  new QLabel(TR("description :"), vtab);
   if (! visit) {
-    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()),
+    connect(new SmallPushButton(TR("Editor"), vtab), SIGNAL(clicked()),
 	    this, SLOT(edit_description()));
   }
   comment = new MultiLineEdit(grid);
@@ -252,7 +255,7 @@ PinDialog::PinDialog(PinData * pi)
   grid->setSpacing(5);
   
   kvtable = new KeyValuesTable(pi->browser_node, grid, visit);
-  addTab(grid, "Properties");
+  addTab(grid, TR("Properties"));
   
   //
     
@@ -297,9 +300,9 @@ void PinDialog::init_tab(QWidget *& tab, MultiLineEdit *& ed, const char * v,
   
   QVBox * vtab = new QVBox(grid);
   
-  new QLabel("selection : ", vtab);
+  new QLabel(TR("selection : "), vtab);
   if (! visit)
-    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()), this, sl);
+    connect(new SmallPushButton(TR("Editor"), vtab), SIGNAL(clicked()), this, sl);
   ed = new MultiLineEdit(grid);
 
   QFont font = ed->font();
@@ -321,13 +324,13 @@ void PinDialog::init_tab(QWidget *& tab, MultiLineEdit *& ed, const char * v,
 void PinDialog::menu_type() {
   QPopupMenu m(0);
 
-  m.insertItem("Choose", -1);
+  m.insertItem(TR("Choose"), -1);
   m.insertSeparator();
   
   int index = list.findIndex(edtype->currentText().stripWhiteSpace());
   
   if (index != -1)
-    m.insertItem("Select in browser", 0);
+    m.insertItem(TR("Select in browser"), 0);
   
   BrowserNode * bn = 0;
   
@@ -335,11 +338,11 @@ void PinDialog::menu_type() {
     bn = BrowserView::selected_item();
     
     if ((bn != 0) && (bn->get_type() == UmlClass) && !bn->deletedp())
-      m.insertItem("Choose class selected in browser", 1);
+      m.insertItem(TR("Choose class selected in browser"), 1);
     else
       bn = 0;
     
-    m.insertItem("Create class and choose it", 2);
+    m.insertItem(TR("Create class and choose it"), 2);
   }
   
   if (!visit || (index != -1) || (bn != 0)) {
@@ -407,7 +410,7 @@ void PinDialog::accept() {
       ((BrowserNode *) bn->parent())->wrong_child_name(s, UmlActivityPin,
 						       bn->allow_spaces(),
 						       bn->allow_empty()))
-    msg_critical("Error", s + "\n\nillegal name or already used");
+    msg_critical(TR("Error"), s + TR("\n\nillegal name or already used"));
   else {
     // check consistency
     UmlParamDirection dir = direction(eddir->currentText());
@@ -416,22 +419,22 @@ void PinDialog::accept() {
     QString err;
     
     if ((dir == UmlIn) && exception)
-      err = "An input pin cannot be an exception.\n";
+      err = TR("An input pin cannot be an exception.\n");
     switch (effect) {
     case UmlDelete:
       if ((dir != UmlIn) && (dir != UmlInOut))
-	err += "Only in and inout pin may have a delete effect.";
+	err += TR("Only in and inout pin may have a delete effect.");
       break;
     case UmlCreate:
       if ((dir != UmlOut) && (dir != UmlInOut) && (dir != UmlReturn))
-	err += "Only out, inout and return pin may have a create effect.";
+	err += TR("Only out, inout and return pin may have a create effect.");
       break;
     default:
       break;
     }
     
     if (!err.isEmpty())
-      msg_critical("Error", err);
+      msg_critical(TR("Error"), err);
     else {
       bn->set_name(s);
       
