@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -34,6 +34,7 @@
 
 class QPushButton;
 class QComboBox;
+class QCheckBox;
 
 class LineEdit;
 class MultiLineEdit;
@@ -63,6 +64,7 @@ class StateDialog : public QTabDialog {
     LineEdit * edname;
     QComboBox * edstereotype;
     QComboBox * edspecification;
+    QCheckBox * active_cb;
     MultiLineEdit * comment;
     QList<BodyDialog> edits;
     
