@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2009 Bruno PAGES  .
+// Copyright 2004-2009 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -75,14 +75,16 @@
 #include "MyTable.h"
 #include "UmlPixmap.h"
 #include "strutil.h"
+#include "translate.h"
 
 QSize StereotypesDialog::previous_size;
 
 StereotypesDialog::StereotypesDialog()
     : QTabDialog(0, "Default stereotypes dialog", TRUE, 0) {
-  setCaption("Default stereotypes dialog");
+  setCaption(TR("Default stereotypes dialog"));
   
-  setCancelButton();
+  setOkButton(TR("OK"));
+  setCancelButton(TR("Cancel"));
   
   const QString space(" ");
   QGrid * grid;
@@ -93,19 +95,19 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("package\nstereotypes : ", grid);
+  new QLabel(TR("package\nstereotypes : "), grid);
   package_list = new LineEdit(grid);
   package_list->setTheText(BrowserPackage::its_default_stereotypes.join(space));
 
-  new QLabel("relations\nstereotypes : ", grid);
+  new QLabel(TR("relations\nstereotypes : "), grid);
   packagetable = new MyTable(1, 1, grid);
-  packagetable->horizontalHeader()->setLabel(0, "Stereotypes");
+  packagetable->horizontalHeader()->setLabel(0, TR("Stereotypes"));
   packagetable->verticalHeader()->setLabel(0, QIconSet(*dependencyButton), "");
   packagetable->setText(0, 0, BrowserPackage::relation_default_stereotypes.join(space));
   packagetable->setColumnStretchable (0, TRUE);
   packagetable->setRowStretchable (0, TRUE);
   
-  addTab(grid, "Package");
+  addTab(grid, TR("Package"));
   
   // class tab
   
@@ -113,21 +115,21 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("class\nstereotypes : ", grid);
+  new QLabel(TR("class\nstereotypes : "), grid);
   class_list = new LineEdit(grid);
   class_list->setTheText(BrowserClass::its_default_stereotypes.join(space));
 
-  new QLabel("attribute\nstereotypes : ", grid);
+  new QLabel(TR("attribute\nstereotypes : "), grid);
   attribute_list = new LineEdit(grid);
   attribute_list->setTheText(BrowserAttribute::its_default_stereotypes.join(space));
 
-  new QLabel("operation\nstereotypes : ", grid);
+  new QLabel(TR("operation\nstereotypes : "), grid);
   operation_list = new LineEdit(grid);
   operation_list->setTheText(BrowserOperation::its_default_stereotypes.join(space));
 
-  new QLabel("relations\nstereotypes : ", grid);
+  new QLabel(TR("relations\nstereotypes : "), grid);
   classtable = new MyTable(9, 1, grid);
-  classtable->horizontalHeader()->setLabel(0, "Stereotypes");
+  classtable->horizontalHeader()->setLabel(0, TR("Stereotypes"));
   classtable->verticalHeader()->setLabel(0, QIconSet(*generalisationButton), "");
   classtable->setText(0, 0, BrowserClass::relations_default_stereotypes[UmlGeneralisation].join(space));
   classtable->verticalHeader()->setLabel(1, QIconSet(*directionalAssociationButton), "");
@@ -148,7 +150,7 @@ StereotypesDialog::StereotypesDialog()
   classtable->setText(8, 0, BrowserClass::relations_default_stereotypes[UmlRealize].join(space));
   classtable->setColumnStretchable (0, TRUE);
   
-  addTab(grid, "Class");
+  addTab(grid, TR("Class"));
   
   // Use case
   
@@ -156,13 +158,13 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("use case\nstereotypes : ", grid);
+  new QLabel(TR("use case\nstereotypes : "), grid);
   usecase_list = new LineEdit(grid);
   usecase_list->setTheText(BrowserUseCase::its_default_stereotypes.join(space));
 
-  (void) new QLabel("relations\nstereotypes : ", grid);
+  (void) new QLabel(TR("relations\nstereotypes : "), grid);
   usecasetable = new MyTable(3, 1, grid);
-  usecasetable->horizontalHeader()->setLabel(0, "Stereotypes");
+  usecasetable->horizontalHeader()->setLabel(0, TR("Stereotypes"));
   usecasetable->verticalHeader()->setLabel(0, QIconSet(*generalisationButton), "");
   usecasetable->setText(0, 0, BrowserUseCase::relations_default_stereotypes[UmlGeneralisation].join(space));
   usecasetable->verticalHeader()->setLabel(1, QIconSet(*associationButton), "");
@@ -174,7 +176,7 @@ StereotypesDialog::StereotypesDialog()
   usecasetable->setRowStretchable (1, TRUE);
   usecasetable->setRowStretchable (2, TRUE);
   
-  addTab(grid, "UseCase");
+  addTab(grid, TR("Use Case"));
   
   // artifact tab
   
@@ -182,19 +184,19 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("artifact\nstereotypes : ", grid);
+  new QLabel(TR("artifact\nstereotypes : "), grid);
   artifact_list = new LineEdit(grid);
   artifact_list->setTheText(BrowserArtifact::its_default_stereotypes.join(space));
 
-  new QLabel("relations\nstereotypes : ", grid);
+  new QLabel(TR("relations\nstereotypes : "), grid);
   artifacttable = new MyTable(1, 1, grid);
-  artifacttable->horizontalHeader()->setLabel(0, "Stereotypes");
+  artifacttable->horizontalHeader()->setLabel(0, TR("Stereotypes"));
   artifacttable->verticalHeader()->setLabel(0, QIconSet(*dependencyButton), "");
   artifacttable->setText(0, 0, BrowserArtifact::relation_default_stereotypes.join(space));
   artifacttable->setColumnStretchable (0, TRUE);
   artifacttable->setRowStretchable (0, TRUE);
   
-  addTab(grid, "Artifact");
+  addTab(grid, TR("Artifact"));
   
   // view
   
@@ -202,23 +204,23 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("class view\nstereotypes : ", grid);
+  new QLabel(TR("class view\nstereotypes : "), grid);
   classview_list = new LineEdit(grid);
   classview_list->setTheText(BrowserClassView::its_default_stereotypes.join(space));
 
-  new QLabel("use case view\nstereotypes : ", grid);
+  new QLabel(TR("use case view\nstereotypes : "), grid);
   usecaseview_list = new LineEdit(grid);
   usecaseview_list->setTheText(BrowserUseCaseView::its_default_stereotypes.join(space));
 
-  new QLabel("component view\nstereotypes : ", grid);
+  new QLabel(TR("component view\nstereotypes : "), grid);
   componentview_list = new LineEdit(grid);
   componentview_list->setTheText(BrowserComponentView::its_default_stereotypes.join(space));
 
-  new QLabel("deployment view\nstereotypes : ", grid);
+  new QLabel(TR("deployment view\nstereotypes : "), grid);
   deploymentview_list = new LineEdit(grid);
   deploymentview_list->setTheText(BrowserDeploymentView::its_default_stereotypes.join(space));
 
-  addTab(grid, "Views");
+  addTab(grid, TR("Views"));
   
   // diagrams
   
@@ -226,43 +228,43 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("class diagram\nstereotypes : ", grid);
+  new QLabel(TR("class diagram\nstereotypes : "), grid);
   classdiagram_list = new LineEdit(grid);
   classdiagram_list->setTheText(BrowserClassDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("object diagram\nstereotypes : ", grid);
+  new QLabel(TR("object diagram\nstereotypes : "), grid);
   objectdiagram_list = new LineEdit(grid);
   objectdiagram_list->setTheText(BrowserObjectDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("communication diagram\nstereotypes : ", grid);
+  new QLabel(TR("communication diagram\nstereotypes : "), grid);
   coldiagram_list = new LineEdit(grid);
   coldiagram_list->setTheText(BrowserColDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("sequence diagram\nstereotypes : ", grid);
+  new QLabel(TR("sequence diagram\nstereotypes : "), grid);
   seqdiagram_list = new LineEdit(grid);
   seqdiagram_list->setTheText(BrowserSeqDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("use case diagram\nstereotypes : ", grid);
+  new QLabel(TR("use case diagram\nstereotypes : "), grid);
   usecasediagram_list = new LineEdit(grid);
   usecasediagram_list->setTheText(BrowserUseCaseDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("state diagram\nstereotypes : ", grid);
+  new QLabel(TR("state diagram\nstereotypes : "), grid);
   statediagram_list = new LineEdit(grid);
   statediagram_list->setTheText(BrowserStateDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("activity diagram\nstereotypes : ", grid);
+  new QLabel(TR("activity diagram\nstereotypes : "), grid);
   activitydiagram_list = new LineEdit(grid);
   activitydiagram_list->setTheText(BrowserActivityDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("component diagram\nstereotypes : ", grid);
+  new QLabel(TR("component diagram\nstereotypes : "), grid);
   componentdiagram_list = new LineEdit(grid);
   componentdiagram_list->setTheText(BrowserComponentDiagram::its_default_stereotypes.join(space));
 
-  new QLabel("deployment diagram\nstereotypes : ", grid);
+  new QLabel(TR("deployment diagram\nstereotypes : "), grid);
   deploymentdiagram_list = new LineEdit(grid);
   deploymentdiagram_list->setTheText(BrowserDeploymentDiagram::its_default_stereotypes.join(space));
 
-  addTab(grid, "Diagrams");
+  addTab(grid, TR("Diagrams"));
   
   // activities
   
@@ -270,55 +272,55 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("activity\nstereotypes : ", grid);
+  new QLabel(TR("activity\nstereotypes : "), grid);
   activity_list = new LineEdit(grid);
   activity_list->setTheText(BrowserActivity::its_default_stereotypes.join(space));
 
-  new QLabel("interruptible activity\nregion stereotypes : ", grid);
+  new QLabel(TR("interruptible activity\nregion stereotypes : "), grid);
   interruptibleactivityregion_list = new LineEdit(grid);
   interruptibleactivityregion_list->setTheText(BrowserInterruptibleActivityRegion::its_default_stereotypes.join(space));
 
-  new QLabel("expansion region\nstereotypes : ", grid);
+  new QLabel(TR("expansion region\nstereotypes : "), grid);
   expansionregion_list = new LineEdit(grid);
   expansionregion_list->setTheText(BrowserExpansionRegion::its_default_stereotypes.join(space));
 
-  new QLabel("partition\nstereotypes : ", grid);
+  new QLabel(TR("partition\nstereotypes : "), grid);
   activitypartition_list = new LineEdit(grid);
   activitypartition_list->setTheText(BrowserActivityPartition::its_default_stereotypes.join(space));
 
-  new QLabel("parameter\nstereotypes : ", grid);
+  new QLabel(TR("parameter\nstereotypes : "), grid);
   parameter_list = new LineEdit(grid);
   parameter_list->setTheText(BrowserParameter::its_default_stereotypes.join(space));
 
-  new QLabel("parameter set\nstereotypes : ", grid);
+  new QLabel(TR("parameter set\nstereotypes : "), grid);
   parameterset_list = new LineEdit(grid);
   parameterset_list->setTheText(BrowserParameterSet::its_default_stereotypes.join(space));
 
-  new QLabel("activity control node\nstereotypes : ", grid);
+  new QLabel(TR("activity control node\nstereotypes : "), grid);
   activitynode_list = new LineEdit(grid);
   activitynode_list->setTheText(BrowserActivityNode::its_default_stereotypes.join(space));
 
-  new QLabel("activity action\nstereotypes : ", grid);
+  new QLabel(TR("activity action\nstereotypes : "), grid);
   activityaction_list = new LineEdit(grid);
   activityaction_list->setTheText(BrowserActivityAction::its_default_stereotypes.join(space));
 
-  new QLabel("activity object node\nstereotypes : ", grid);
+  new QLabel(TR("activity object node\nstereotypes : "), grid);
   activityobject_list = new LineEdit(grid);
   activityobject_list->setTheText(BrowserActivityObject::its_default_stereotypes.join(space));
 
-  new QLabel("pin\nstereotypes : ", grid);
+  new QLabel(TR("pin\nstereotypes : "), grid);
   pin_list = new LineEdit(grid);
   pin_list->setTheText(BrowserPin::its_default_stereotypes.join(space));
 
-  new QLabel("expansion node\nstereotypes : ", grid);
+  new QLabel(TR("expansion node\nstereotypes : "), grid);
   expansionnode_list = new LineEdit(grid);
   expansionnode_list->setTheText(BrowserExpansionNode::its_default_stereotypes.join(space));
 
-  new QLabel("flow\nstereotypes : ", grid);
+  new QLabel(TR("flow\nstereotypes : "), grid);
   flow_list = new LineEdit(grid);
   flow_list->setTheText(BrowserFlow::its_default_stereotypes.join(space));
 
-  addTab(grid, "Activities");
+  addTab(grid, TR("Activities"));
   
   // others
   
@@ -326,27 +328,31 @@ StereotypesDialog::StereotypesDialog()
   grid->setMargin(5);
   grid->setSpacing(5);
   
-  new QLabel("state\nstereotypes : ", grid);
+  new QLabel(TR("state\nstereotypes : "), grid);
   state_list = new LineEdit(grid);
   state_list->setTheText(BrowserState::its_default_stereotypes.join(space));
 
-  new QLabel("pseudostate\nstereotypes : ", grid);
+  new QLabel(TR("pseudostate\nstereotypes : "), grid);
   pseudostate_list = new LineEdit(grid);
   pseudostate_list->setTheText(BrowserPseudoState::its_default_stereotypes.join(space));
 
-  new QLabel("state action\nstereotypes : ", grid);
+  new QLabel(TR("state action\nstereotypes : "), grid);
   stateaction_list = new LineEdit(grid);
   stateaction_list->setTheText(BrowserStateAction::its_default_stereotypes.join(space));
 
-  new QLabel("component\nstereotypes : ", grid);
+  new QLabel(TR("component\nstereotypes : "), grid);
   component_list = new LineEdit(grid);
   component_list->setTheText(BrowserComponent::its_default_stereotypes.join(space));
 
-  new QLabel("node\nstereotypes : ", grid);
+  new QLabel(TR("node\nstereotypes : "), grid);
   node_list = new LineEdit(grid);
   node_list->setTheText(BrowserDeploymentNode::its_default_stereotypes.join(space));
 
-  addTab(grid, "Others");
+  new QLabel(TR("message\nstereotypes : "), grid);
+  msg_list = new LineEdit(grid);
+  msg_list->setTheText(BrowserSeqDiagram::message_default_stereotypes.join(space));
+
+  addTab(grid, TR("Others"));
 }
 
 StereotypesDialog::~StereotypesDialog() {
@@ -467,6 +473,9 @@ void StereotypesDialog::accept() {
   BrowserDeploymentNode::its_default_stereotypes =
     QStringList::split(space, node_list->theText());
   
+  BrowserSeqDiagram::message_default_stereotypes =
+    QStringList::split(space, msg_list->theText());
+  
   BrowserClassView::its_default_stereotypes =
     QStringList::split(space, classview_list->theText());
   
